<?xml version="1.0" encoding="utf-8"?>

<!-- 
	Version 2.6
	27 March 2006

	Author:
		Laurent Desqueper
-->

<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:ectd="http://www.ich.org/ectd" 
	xmlns:xlink="http://www.w3c.org/1999/xlink">

<!-- include combination and layout style sheets -->
<xsl:include href="common.xsl"/>
<xsl:include href="combined.xsl"/>
<xsl:include href="layout.xsl"/>

<!-- style sheet parameters -->
<xsl:param name="docpos"/>			<!-- The position of the PI to generate in the document zone -->
<xsl:param name="depth"/>			<!-- The level where the generate the PI as Integer: prd(0), frm(1), str(2), prs(3) -->
<xsl:param name="lang"/>				<!-- The language of the PI document to generate -->
<xsl:param name="caller"/>			<!-- The caller of the stylesheet : if empty, caller is the PIM Viewer -->
<xsl:param name="section"/>			<!-- The section to display : if empty, all document displays -->

<!-- style sheet version number -->
<xsl:param name="xsl-ver">2.6</xsl:param>

<!-- set output type to XHTML -->
<xsl:output indent="yes" method="xml"/>

<!-- structure of the document -->
<xsl:template match="/">
	<html>
		<head>
			<title>
				<xsl:call-template name="getHeadingText"><xsl:with-param name="id">anx2</xsl:with-param></xsl:call-template>
			</title>
			<link href="util/style/doc.css" rel="stylesheet"/>
		</head>
		<body background="util/style/watermark.gif">
			<xsl:if test="$section =''">
																																																					<!-- COMMENTS -->
				<xsl:if test="count(/pim/documents/document[position() = $docpos]/comment[string-length(@section) = 0 and @lang=$lang]) > 0">
					<b><u>Comment on <xsl:call-template name="getDocumentType"/>:</u></b>
					<ul>
						<xsl:apply-templates select="/pim/documents/document[position() = $docpos]/comment[string-length(@section) = 0 and @lang=$lang]" mode="doc"/>
					</ul>
				</xsl:if>
			</xsl:if>
			
			<xsl:variable name="nManufacturerActive">
				<xsl:call-template name="countElement">
					<xsl:with-param name="level">2</xsl:with-param>
					<xsl:with-param name="element">manufacturer_active</xsl:with-param>
				</xsl:call-template>
			</xsl:variable>
			<xsl:variable name="nManufacturerBatch">
				<xsl:call-template name="countElement">
					<xsl:with-param name="level">2</xsl:with-param>
					<xsl:with-param name="element">manufacturer_batch</xsl:with-param>
				</xsl:call-template>
			</xsl:variable>
			<xsl:variable name="headingA">
				<xsl:choose>
					<xsl:when test="$nManufacturerActive = 0">
						<xsl:choose>
							<xsl:when test="$nManufacturerBatch > 1">anx2_a_batch_plural</xsl:when>
							<xsl:otherwise>anx2_a_batch_singular</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:when test="$nManufacturerActive = 1">
						<xsl:choose>
							<xsl:when test="$nManufacturerBatch > 1">anx2_a_as_singular_batch_plural</xsl:when>
							<xsl:otherwise>anx2_a_as_singular_batch_singular</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:choose>
							<xsl:when test="$nManufacturerBatch > 1">anx2_a_as_plural_batch_plural</xsl:when>
							<xsl:otherwise>anx2_a_as_plural_batch_singular</xsl:otherwise>
						</xsl:choose>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:variable>
																																																					<!-- TITLE -->
			<xsl:if test="$section =''">
				<center>
					<h1>
						<br style="line-height: 98mm"/>
						<xsl:call-template name="getHeadingText">
							<xsl:with-param name="id">anx2</xsl:with-param>
						</xsl:call-template>
					</h1>
				</center>
				<br/>
																																																					<!-- TOC -->
				<center>
					<table width="70%" cellpadding="0" cellspacing="0" style="color:black">
						<tr>
							<td width="30px">
								<h1>
									<xsl:call-template name="getHeadingNumber"><xsl:with-param name="id" select="$headingA"/></xsl:call-template>
								</h1>
							</td>
							<td>
								<h1>
									<xsl:call-template name="getHeadingText"><xsl:with-param name="id" select="$headingA"/></xsl:call-template>
								</h1>
							</td>
						</tr>
						<tr class="separator"><td><xsl:text> </xsl:text></td></tr>
						<tr>
							<td width="30px">
								<h1>
									<xsl:call-template name="getHeadingNumber"><xsl:with-param name="id">anx2_b</xsl:with-param></xsl:call-template>
								</h1>
							</td>
							<td>
								<h1>
									<xsl:call-template name="getHeadingText"><xsl:with-param name="id">anx2_b</xsl:with-param></xsl:call-template>
								</h1>
							</td>
						</tr>
						<xsl:if test="/pim/level_product/approval/@mode != 'complete'">
							<tr class="separator"><td><xsl:text> </xsl:text></td></tr>
							<tr>
								<td width="30px">
									<h1>
										<xsl:call-template name="getHeadingNumber"><xsl:with-param name="id">anx2_c</xsl:with-param></xsl:call-template>
									</h1>
								</td>
								<td>
									<h1>
										<xsl:call-template name="getHeadingText"><xsl:with-param name="id">anx2_c</xsl:with-param></xsl:call-template>
									</h1>
								</td>
							</tr>
						</xsl:if>
					</table>
					<br style="line-height: 30mm"/>
				</center>
			</xsl:if>
			
			<table cellpadding="1" cellspacing="0" width="100%" style="color:black">
				<xsl:if test="$section = '' or $section = 'anx2_a'">
																																																					<!-- SECTION A -->
					<xsl:call-template name="displayHeading">
						<xsl:with-param name="id" select="$headingA"/>
						<xsl:with-param name="secnr">A</xsl:with-param>
					</xsl:call-template>
																																																					<!-- SECTION A 1 -->
					<xsl:if test="$nManufacturerActive > 0">
						<xsl:choose>
							<xsl:when test="$nManufacturerActive = 1">
								<xsl:call-template name="displayUnderlinedHeading">
									<xsl:with-param name="id">anx2_a1_singular</xsl:with-param>
								</xsl:call-template>
							</xsl:when>
							<xsl:otherwise>
								<xsl:call-template name="displayUnderlinedHeading">
									<xsl:with-param name="id">anx2_a1_plural</xsl:with-param>
								</xsl:call-template>
							</xsl:otherwise>
						</xsl:choose>
						<xsl:call-template name="displayElement">
							<xsl:with-param name="level">2</xsl:with-param>
							<xsl:with-param name="element">manufacturer_active</xsl:with-param>
						</xsl:call-template>
						<xsl:call-template name="displaySeparator"/>
					</xsl:if>
																																																					<!-- SECTION A 2 -->
					<xsl:choose>
						<xsl:when test="$nManufacturerBatch = 1">
							<xsl:call-template name="displayUnderlinedHeading">
								<xsl:with-param name="id">anx2_a2_singular</xsl:with-param>
							</xsl:call-template>
						</xsl:when>
						<xsl:otherwise>
							<xsl:call-template name="displayUnderlinedHeading">
								<xsl:with-param name="id">anx2_a2_plural</xsl:with-param>
							</xsl:call-template>
						</xsl:otherwise>
					</xsl:choose>
					<xsl:call-template name="displayElement">
						<xsl:with-param name="level">2</xsl:with-param>
						<xsl:with-param name="element">manufacturer_batch</xsl:with-param>
					</xsl:call-template>
					<xsl:if test="$nManufacturerBatch > 1">
						<xsl:call-template name="displaySeparator"/>
						<xsl:call-template name="displayText">
							<xsl:with-param name="id">anx2_a3</xsl:with-param>
						</xsl:call-template>
					</xsl:if>
				</xsl:if>
				<xsl:call-template name="displaySeparator"/>
				<xsl:call-template name="displaySeparator"/>

				<xsl:if test="$section = '' or $section = 'anx2_b'">
																																																					<!-- SECTION B -->
					<xsl:call-template name="displayHeading">
						<xsl:with-param name="id">anx2_b</xsl:with-param>
						<xsl:with-param name="secnr">B</xsl:with-param>
					</xsl:call-template>
																																																					<!-- SECTION B 1 -->
					<xsl:call-template name="displayBulletHeading">
						<xsl:with-param name="id">anx2_b1</xsl:with-param>
					</xsl:call-template>
					<xsl:apply-templates select="/pim/level_product" mode="legalStatus"/>
					<xsl:call-template name="displaySeparator"/>
																																																					<!-- SECTION B 2 -->
					<xsl:call-template name="displayBulletHeading">
						<xsl:with-param name="id">anx2_b2</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="displayElement">
						<xsl:with-param name="level">3</xsl:with-param>
						<xsl:with-param name="element">safe_use</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="displaySeparator"/>
																																																					<!-- SECTION B 3 -->
					<xsl:variable name="nPsurStatement">
						<xsl:call-template name="countElement">
							<xsl:with-param name="level">3</xsl:with-param>
							<xsl:with-param name="element">psur_statement</xsl:with-param>
						</xsl:call-template>
					</xsl:variable>
					<xsl:if test="$nPsurStatement > 0">
						<xsl:call-template name="displayBulletHeading">
							<xsl:with-param name="id">anx2_b3</xsl:with-param>
						</xsl:call-template>
						<xsl:call-template name="displayElement">
							<xsl:with-param name="level">3</xsl:with-param>
							<xsl:with-param name="element">psur_statement</xsl:with-param>
						</xsl:call-template>
						<xsl:call-template name="displaySeparator"/>
					</xsl:if>
				</xsl:if>
				<xsl:call-template name="displaySeparator"/>
																																																					<!-- SECTION C -->
				<xsl:if test="/pim/level_product/approval/@mode != 'complete'">
					<xsl:if test="$section = '' or $section = 'anx2_c'">
						<xsl:call-template name="displayHeading">
							<xsl:with-param name="id">anx2_c</xsl:with-param>
							<xsl:with-param name="secnr">C</xsl:with-param>
						</xsl:call-template>
						<xsl:call-template name="displayText">
							<xsl:with-param name="id">anx2_c1</xsl:with-param>
						</xsl:call-template>
						<xsl:call-template name="displayElement">
							<xsl:with-param name="level">3</xsl:with-param>
							<xsl:with-param name="element">obligations</xsl:with-param>
						</xsl:call-template>
					</xsl:if>
				</xsl:if>
			</table>
			<br/>
			<br/>
			<xsl:if test="$section ='' and $caller = ''">
				<font size="-5" style="font-weight: normal">Annex2 style sheet version <xsl:value-of select="$xsl-ver"/></font>
			</xsl:if>
			<br/>
		</body>
	</html>
</xsl:template>

<!-- Special case of Section B1 : legal status -->
<xsl:template match="*" mode="legalStatus">
	
	<xsl:variable name="firstValue" select=".//level_presentation[1]/legal_status/@case"/>
	<xsl:variable name="comparison">
		<xsl:for-each select=".//level_presentation">
			<xsl:if test="$firstValue != legal_status/@case">N</xsl:if>
		</xsl:for-each>
	</xsl:variable>
	
	<xsl:choose>
		<xsl:when test="contains($comparison, 'N')">
			<xsl:apply-templates select="*[starts-with(name(), 'level_')]" mode="legalStatus"/>
		</xsl:when>
		<xsl:otherwise>
			<tr>
				<xsl:if test="$caller = 'pimrs'">
					<td><xsl:text> </xsl:text></td>
				</xsl:if>
				<xsl:choose>
					<xsl:when test="name() = 'level_product'">
						<td width="100%">
							<font color="blue">
								<xsl:call-template name="getHeadingText"><xsl:with-param name="id" select="$firstValue"/></xsl:call-template>
							</font>
						</td>
					</xsl:when>
					<xsl:otherwise>
						<td width="100%" class="combined">
							<font size="-2">
								[
								<xsl:for-each select="ancestor-or-self::*">
									<xsl:value-of select="@name"/><xsl:text> </xsl:text>
								</xsl:for-each>
								]
							</font>
							<br/>
							<font color="blue">
								<xsl:call-template name="getHeadingText"><xsl:with-param name="id" select="$firstValue"/></xsl:call-template>
							</font>
						</td>
					</xsl:otherwise>
				</xsl:choose>
			</tr>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

</xsl:stylesheet>