<?xml version="1.0" encoding="utf-8"?>

<!-- 
	Version 2.6
	23 February 2006

	Author:
		Laurent Desqueper
-->

<xsl:stylesheet version="1.0" 
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:ectd="http://www.ich.org/ectd" 
	xmlns:xlink="http://www.w3c.org/1999/xlink">

<xsl:param name="xsl-ver">2.6</xsl:param>

<xsl:output indent="yes" method="html"/>

<!-- Key used for the indirection from the document zone to the tree zone -->
<xsl:key name = "level_id" match = "*" use = "@level_id" /> 

<xsl:template match="/">
	<html>
	<head>
		<title>PIM</title>
		<link href="util/style/pim.css" rel="stylesheet"/>
		<script>
			var lang = "en";
			var xmlurl = "" + document.location;
			var slashp = xmlurl.lastIndexOf("/");
			var xmldir = xmlurl.substring(0, slashp+1);
			
			// Change language for PI generation
			function setlang(newlang)
			{
				if(document.getElementById("lang-" + lang))
					document.getElementById("lang-" + lang).style.fontWeight = "normal";
				lang = newlang;
				if(document.getElementById("lang-" + lang))
					document.getElementById("lang-" + lang).style.fontWeight = "bold";
			}
			
			// Generate PI
			// - context is the type of PI to generate (spc, annex2, outer, blister, immed or leaflet)
			// - docpos is the position of the document element in the document zone
			// - depth corresponds to the numeric value for prd(0), frm(1), str(2) and prs(3)
			function generate(context, docpos, depth)
			{
				if(typeof XMLHttpRequest=='undefined')
					generate_ie(context, docpos, depth);
				else
  					generate_ff(context, docpos, depth);
			}
			
			// Generate PI in Internet Explorer browser
			// - context is the type of PI to generate (spc, annex2, outer, blister, immed or leaflet)
			// - docpos is the position of the document element in the document zone
			// - depth corresponds to the numeric value for prd(0), frm(1), str(2) and prs(3)
			function generate_ie(context, docpos, depth)
			{
				var xml = new ActiveXObject("MSXML2.DOMDocument.3.0");
		  		var xsl = new ActiveXObject("MSXML2.FreeThreadedDOMDocument.3.0");
				var template = new ActiveXObject("MSXML2.XSLTemplate.3.0");

		  		xml.load(xmlurl);

				xsl.load("util/style/" + context + ".xsl");
		  		template.stylesheet=xsl;
  
		  		var proc = template.createProcessor();
		  		proc.input=xml;

				proc.addParameter("xmldir", xmldir);
				proc.addParameter("docpos", docpos);
				proc.addParameter("depth", depth);
				proc.addParameter("lang", lang);
  
		  		proc.transform();
				var popup = window.open('', context, 'alwaysRaised=1, dependent=1, height=600, location=0, menubar=1, personalbar=1, scrollbars=1, status=1, toolbar=0, width=800, resizable=1, left=20, top=10');
				popup.focus();
	  			popup.document.write(proc.output);
			}
			
			// Generate PI in FireFox browser
			// - context is the type of PI to generate (spc, annex2, outer, blister, immed or leaflet)
			// - docpos is the position of the document element in the document zone
			// - depth corresponds to the numeric value for prd(0), frm(1), str(2) and prs(3)
			function generate_ff(context, docpos, depth)
			{
				var xmlhttp = new XMLHttpRequest();

				xmlhttp.open("GET", "util/style/" + context + ".xsl", true);
				xmlhttp.onreadystatechange=function() {
   					if (xmlhttp.readyState==4) {
						var xsltProcessor = new XSLTProcessor();
						var xslStylesheet = xmlhttp.responseXML;
						xsltProcessor.importStylesheet(xslStylesheet);
		
						xmlhttp2 = new XMLHttpRequest();
						xmlhttp2.open("GET", xmlurl, true);
						xmlhttp2.onreadystatechange=function() {
   							if (xmlhttp2.readyState==4) {
								var xmlDoc = xmlhttp2.responseXML;

								xsltProcessor.setParameter(null,"xmldir", xmldir);
								xsltProcessor.setParameter(null,"docpos", docpos);
								xsltProcessor.setParameter(null,"depth", depth);
								xsltProcessor.setParameter(null,"lang", lang);
	
								xmlDoc = xsltProcessor.transformToDocument(xmlDoc);
		
								var xmls = new XMLSerializer();
								var output = xmls.serializeToString(xmlDoc);

								var popup = window.open('', context, 'alwaysRaised=1, dependent=1, height=600, location=0, menubar=1, personalbar=1, scrollbars=1, status=1, toolbar=0, width=800, resizable=1, screenX=20, screenY=10');
								popup.focus();
	  							popup.document.write(output);
								popup.document.close();
   							}
  						}
						xmlhttp2.send(null);
   					}
  				}
				xmlhttp.send(null);
			}
		</script>
	</head>
	<body>
		<center>
			<table width="90%" class="panel" cellspacing="0" cellpadding="5">
				<tr>
					<td width="200" class="transparent" valign="top">
						<br/><br/><br/>
						<img src="util/style/pim.gif" width="84"/>
					</td>
  					<td width="100%" class="transparent">
						<br/>
						<b>PIM Submission</b>
						<xsl:text> </xsl:text>
						(Ver. <xsl:value-of select="/pim/pim-envelope/des-version"/>)
						<br/><br/>
						<xsl:apply-templates select="/pim/pim-envelope"/>
  			     	</td>
				</tr>
			</table>
			
			<table width="90%" class="panel" style="border-bottom-width: 1px; border-bottom-color: black; border-bottom-style: solid" cellspacing="0" cellpadding="0">
				<tr>
					<td colspan="2" class="transparent">
						Provided languages: 
						<xsl:apply-templates select="/pim/templates/multilang"/>
					</td>
				</tr>
				<tr>
					<td width="25%" class="topleft" bgcolor="#E1E1FF">Product</td>
					<td width="75%">
						<table width="100%" class="panel" cellspacing="0" cellpadding="0">
							<tr>
								<td width="33%" class="topleft" bgcolor="#E1E1FF">Form</td>
								<td width="67%">
									<table width="100%" class="panel" cellspacing="0" cellpadding="0">
										<tr>
											<td width="50%" class="topleft" bgcolor="#E1E1FF">Strength</td>
											<td width="50%">
												<table width="100%" class="panel" cellspacing="0" cellpadding="0">
													<tr>
														<td width="100%" class="topsides" bgcolor="#E1E1FF">Presentation</td>
													</tr>
												</table>
											</td>
										</tr>
									</table>
								</td>
							</tr>
						</table>
					</td>
				</tr>
				<xsl:apply-templates select="/pim/level_product"/>
			</table>
			<table width="90%" class="panel" cellspacing="0" cellpadding="0">
				<tr>
					<td colspan="2" class="transparent">
						<font size="-5">
							PIM style sheet version <xsl:value-of select="$xsl-ver"/>
						</font>
					</td>
				</tr>
			</table>
		</center>
	</body>
	</html>
</xsl:template>

<xsl:template match="pim-envelope">
	<table width="100%" cellspacing="0" cellpadding="0">
		<tr>
			<td class="topleft" width="15%" bgcolor="#E1E1FF">Application :</td>
			<td class="topleft" width="15%">
				<xsl:if test="count(application/number)=0">-</xsl:if>
				<xsl:apply-templates select="application/number"/>
			</td>
			<xsl:choose>
				<xsl:when test="count(submission) = 1">
					<td class="topleft" width="15%" bgcolor="#E1E1FF">Submission :</td>
					<td class="topleft" width="15%">
						<xsl:if test="count(submission)=0">-</xsl:if>
						<xsl:apply-templates select="submission"/>
					</td>
				</xsl:when>
				<xsl:otherwise>
					<td colspan="2" class="topleft" width="30%">Migration</td>
				</xsl:otherwise>
			</xsl:choose>
			<td class="topleft" width="15%" bgcolor="#E1E1FF">Inn :</td>
			<td class="topsides" width="15%">
				<xsl:if test="count(inn)=0">-</xsl:if>
				<xsl:apply-templates select="inn"/>
			</td>
		</tr>
		<tr>
			<td class="topleft" bgcolor="#E1E1FF">Applicant :</td>
			<td class="topleft">
				<xsl:if test="count(applicant)=0">-</xsl:if>
				<xsl:apply-templates select="applicant"/>
			</td>
			<td class="topleft" bgcolor="#E1E1FF">Procedure :</td>
			<td class="topleft">
				<xsl:if test="count(procedure)=0">-</xsl:if>
				<xsl:apply-templates select="procedure"/><br/>
				<xsl:if test="count(submission)>0">
					Day <xsl:apply-templates select="submission/@step-day"/>
				</xsl:if>
			</td>
			<td class="topleft" bgcolor="#E1E1FF">eCTD Seq. :</td>
			<td class="topsides">
				<xsl:if test="count(ectd-sequence)=0">-</xsl:if>
				<xsl:apply-templates select="ectd-sequence"/>
			</td>
		</tr>
		<tr>
			<td class="topleft" bgcolor="#E1E1FF">Agency :</td>
			<td class="topleft">
				<xsl:if test="count(agency-name)=0">-</xsl:if>
				<xsl:apply-templates select="agency-name"/>
			</td>
			<td class="topleft" bgcolor="#E1E1FF">Invented Name :</td>
			<td class="topleft">
				<xsl:if test="count(invented-name)=0">-</xsl:if>
				<xsl:apply-templates select="invented-name"/>
			</td>
			<td class="topleft" bgcolor="#E1E1FF">PIM Seq. :</td>
			<td class="topsides">
				<xsl:if test="count(pim-sequence)=0">-</xsl:if>
				<xsl:apply-templates select="pim-sequence"/>
			</td>
		</tr>
		<tr>
			<td class="topleft" bgcolor="#E1E1FF">Status :</td>
			<td class="topleft">
				<xsl:if test="count(status)=0">-</xsl:if>
				<xsl:apply-templates select="status"/>
			</td>
			<td class="topleft" bgcolor="#E1E1FF">ATC Code :</td>
			<td class="topleft">
				<xsl:if test="count(atc-code)=0">-</xsl:if>
				<xsl:apply-templates select="atc-code"/>
			</td>
			<td class="topleft" bgcolor="#E1E1FF">Related Seq. :</td>
			<td class="topsides">
				<xsl:if test="count(pim-related-sequence)=0">-</xsl:if>
				<xsl:apply-templates select="pim-related-sequence"/>
			</td>
		</tr>
		<tr>
			<td bgcolor="#E1E1FF">
				<xsl:attribute name="class">
					<xsl:choose>
						<xsl:when test="count(/pim/pim-envelope/external-document) + count(/pim/level_product/comment) + count(/pim/level_product/additional_information_o) + count(/pim/level_product/additional_information_p) = 0">topbotleft</xsl:when>
						<xsl:otherwise>topleft</xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
				Description :
			</td>
			<td class="topsides" colspan="5">
				<xsl:attribute name="class">
					<xsl:choose>
						<xsl:when test="count(/pim/pim-envelope/external-document) + count(/pim/level_product/comment) + count(/pim/level_product/additional_information_o) + count(/pim/level_product/additional_information_p) = 0">all</xsl:when>
						<xsl:otherwise>topsides</xsl:otherwise>
					</xsl:choose>
				</xsl:attribute>
				<xsl:if test="count(pim-description)=0">-</xsl:if>
				<xsl:apply-templates select="pim-description"/>
			</td>
		</tr>
		<xsl:if test="count(/pim/level_product/comment) > 0">
			<tr>
				<td bgcolor="#E1E1FF">
					<xsl:attribute name="class">
						<xsl:choose>
							<xsl:when test="count(/pim/pim-envelope/external-document) + count(/pim/level_product/additional_information_o) + count(/pim/level_product/additional_information_p) = 0">topbotleft</xsl:when>
							<xsl:otherwise>topleft</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
					Comments :
				</td>
				<td colspan="5">
					<xsl:attribute name="class">
						<xsl:choose>
							<xsl:when test="count(/pim/pim-envelope/external-document) + count(/pim/level_product/additional_information_o) + count(/pim/level_product/additional_information_p) = 0">all-notcenter</xsl:when>
							<xsl:otherwise>topsides-notcenter</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
					<xsl:for-each select="/pim/level_product/comment">
						<xsl:value-of select="@department"/> : <xsl:value-of select="@reason"/><br/>
					</xsl:for-each>
				</td>
			</tr>
		</xsl:if>
		<xsl:if test="count(/pim/pim-envelope/external-document) > 0">
			<tr>
				<td bgcolor="#E1E1FF" colspan="3">
					<xsl:attribute name="class">
						<xsl:choose>
							<xsl:when test="count(/pim/level_product/comment) + count(/pim/level_product/additional_information_o) + count(/pim/level_product/additional_information_p) = 0">topbotleft</xsl:when>
							<xsl:otherwise>topleft</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
					External Document :
				</td>
				<td class="topsides" colspan="3">
					<xsl:attribute name="class">
						<xsl:choose>
							<xsl:when test="count(/pim/level_product/comment) + count(/pim/level_product/additional_information_o) + count(/pim/level_product/additional_information_p) = 0">all-notcenter</xsl:when>
							<xsl:otherwise>topsides-notcenter</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
					<xsl:for-each select="/pim/pim-envelope/external-document/doc-leaf">
						<a href="{@ref-file}">
							<img src="util/style/file.gif" alt="{@title}" border="0"/>
						</a><xsl:text> </xsl:text><xsl:value-of select="@title"/><br/>			
					</xsl:for-each>
				</td>
			</tr>
		</xsl:if>
		
		<xsl:if test="count(/pim/level_product/additional_information_o) > 0">
			<tr>
				<td colspan="3" bgcolor="#E1E1FF">
					<xsl:attribute name="class">
						<xsl:choose>
							<xsl:when test="count(/pim/level_product/additional_information_p) = 0">topbotleft</xsl:when>
							<xsl:otherwise>topleft</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
					Additional Information to Labelling:
				</td>
				<td colspan="3">
					<xsl:attribute name="class">
						<xsl:choose>
							<xsl:when test="count(/pim/level_product/additional_information_p) = 0">all-notcenter</xsl:when>
							<xsl:otherwise>topsides-notcenter</xsl:otherwise>
						</xsl:choose>
					</xsl:attribute>
					<xsl:for-each select="/pim/level_product/additional_information_o">
						<a>
							<xsl:attribute name="href">javascript:generate('additional', 'additional_information_o', '<xsl:value-of select="position()"/>');</xsl:attribute>
							<img src="util/style/add-o.gif" alt="{@title}" border="0"/>
						</a><xsl:text> </xsl:text><xsl:value-of select="@title"/><br/>
					</xsl:for-each>
				</td>
			</tr>
		</xsl:if>
		<xsl:if test="count(/pim/level_product/additional_information_p) > 0">
			<tr>
				<td colspan="3" bgcolor="#E1E1FF" class="topbotleft">
					Additional Information to Package Leaflet:
				</td>
				<td colspan="3" class="all-notcenter">
					<xsl:for-each select="/pim/level_product/additional_information_p">
						<a>
							<xsl:attribute name="href">javascript:generate('additional', 'additional_information_p', '<xsl:value-of select="position()"/>');</xsl:attribute>
							<img src="util/style/add-p.gif" alt="{@title}" border="0"/>
						</a><xsl:text> </xsl:text><xsl:value-of select="@title"/><br/>
					</xsl:for-each>
				</td>
			</tr>
		</xsl:if>
	</table>
</xsl:template>

<xsl:template match="number|applicant|agency-name|submission|procedure|invented-name|inn|ectd-sequence|pim-sequence|atc-code|pim-related-sequence|pim-description">
	<xsl:value-of select="."/>
	<xsl:if test="position()!=last()"><br/></xsl:if>
</xsl:template>

<xsl:template match="submission">
	<xsl:choose>
		<xsl:when test="@type='initial-maa'">Initial</xsl:when>
		<xsl:when test="@type='var-type1a'">Var. Type 1a</xsl:when>
		<xsl:when test="@type='var-type1b'">Var. Type 1b</xsl:when>
		<xsl:when test="@type='var-type2'">Var. Type 2</xsl:when>
		<xsl:when test="@type='extension'">Extension</xsl:when>
		<xsl:when test="@type='urgent-safety-restriction'">Urgent Safety Restriction</xsl:when>
		<xsl:when test="@type='article-61-3'">Article 61(3)</xsl:when>
		<xsl:when test="@type='renewal'">Renewal</xsl:when>
		<xsl:when test="@type='annual-reassessment'">Annual Reassessment</xsl:when>
		<xsl:when test="@type='transfer-ma'">Transfer of Authorisation</xsl:when>
		<xsl:when test="@type='renewal'">Renewal</xsl:when>
		<xsl:when test="@type='corrigendum'">Corrigendum</xsl:when>
		<xsl:when test="@type='supplementary-info'">Supplementary Information</xsl:when>
		<xsl:when test="@type='exceptional-change'">Exceptional Change</xsl:when>
	</xsl:choose>
</xsl:template>

<xsl:template match="procedure">
	<xsl:choose>
		<xsl:when test="@type='centralised'">Centralised</xsl:when>
	</xsl:choose>
</xsl:template>

<xsl:template match="status">
	<xsl:choose>
		<xsl:when test="@type='under-review'">Under Review</xsl:when>
		<xsl:when test="@type='positive-opinion'">Positive Opinion</xsl:when>
		<xsl:when test="@type='negative-opinion'">Negative Opinion</xsl:when>
		<xsl:when test="@type='final-opinion'">Final Opinion</xsl:when>
		<xsl:when test="@type='approved'">Approved</xsl:when>
		<xsl:when test="@type='rejected'">Rejected</xsl:when>
	</xsl:choose>
</xsl:template>

<xsl:template name="pi-generation">
	<xsl:param name="type"/>
	<xsl:param name="pos"/>
	<xsl:param name="depth"/>

	<xsl:variable name="first" select="/pim/documents/document[$pos]/pi-level[1]/@ref-id"/>
	<xsl:variable name="level" select="name(/pim//*[@level_id = $first])"/>
	<xsl:variable name="effectiveDepth">
		<xsl:choose>
			<xsl:when test="$level = 'level_product'">0</xsl:when>
			<xsl:when test="$level = 'level_form'">1</xsl:when>
			<xsl:when test="$level = 'level_strength'">2</xsl:when>
			<xsl:when test="$level = 'level_presentation'">3</xsl:when>
			<xsl:otherwise>4</xsl:otherwise>
			<!--xsl:when test="count(/pim/documents/document[$pos]/pi-level) > 1"><xsl:value-of select="$depth + 1"/></xsl:when>
			<xsl:otherwise><xsl:value-of select="$depth"/></xsl:otherwise-->
		</xsl:choose>
	</xsl:variable>
	
	<a>
		<xsl:attribute name="href">javascript:generate(
				'<xsl:value-of select="$type"/>',
				'<xsl:value-of select="$pos"/>',
				'<xsl:value-of select="$effectiveDepth"/>');</xsl:attribute>
		<img border="0">
			<xsl:attribute name="src">util/style/<xsl:value-of select="$type"/><xsl:if test="count(/pim/documents/document[$pos]/pi-level) > 1">s</xsl:if>.gif</xsl:attribute>
			<xsl:attribute name="alt"><xsl:choose>
					<xsl:when test="$type='spc'">S.P.C.</xsl:when>
					<xsl:when test="$type='annex2'">Annex II</xsl:when>
					<xsl:when test="$type='outer'">Outer Labelling</xsl:when>
					<xsl:when test="$type='blister'">Blister Labelling</xsl:when>
					<xsl:when test="$type='immed'">Immediate Labelling</xsl:when>
					<xsl:when test="$type='leaflet'">Package Leaflet</xsl:when>
				</xsl:choose> for <xsl:for-each select="/pim/documents/document[$pos]/pi-level"><xsl:variable name="ref-id" select="@ref-id"/>
- <xsl:value-of select="key('level_id', $ref-id)/@name"/>
				</xsl:for-each>
			</xsl:attribute>
		</img>
	</a>
</xsl:template>

<xsl:template match="document">
	<xsl:param name="depth"/>
	<xsl:param name="level"/>
	
	<xsl:variable name="docpos" select="position()"/>
	
	<xsl:if test="count(pi-level[./@ref-id = $level]) = 1 and count(pi-level) = 1">
		<xsl:call-template name="pi-generation">
			<xsl:with-param name="type" select="@type"/>
			<xsl:with-param name="pos" select="position()"/>
			<xsl:with-param name="depth" select="$depth"/>
		</xsl:call-template>
	</xsl:if>
	<xsl:if test="count(pi-level) > 1">
		<xsl:variable name="occur">
			<xsl:for-each select="pi-level">
				<xsl:variable name="ref-id" select="@ref-id"/>
				<xsl:for-each select="/pim//*[@level_id = $level]//*/@level_id">
					<xsl:if test="$ref-id = .">Y</xsl:if>
				</xsl:for-each>
			</xsl:for-each>
		</xsl:variable>
		<xsl:variable name="lower">
			<xsl:for-each select="/pim//*[@level_id = $level]/*[starts-with(name(), 'level')]">
				<xsl:for-each select=".//*/@level_id">
					<xsl:variable name="lvlid" select="."/>
					<xsl:for-each select="/pim/documents/document[$docpos]/pi-level">
						<xsl:variable name="ref-id" select="@ref-id"/>
						<xsl:if test="$ref-id = $lvlid">Y</xsl:if></xsl:for-each></xsl:for-each>,</xsl:for-each>
		</xsl:variable>
		<xsl:variable name="target">
			<xsl:for-each select="pi-level">Y</xsl:for-each>
		</xsl:variable>
		<xsl:if test="string-length($occur) = count(pi-level) and contains($lower, $target) = false">
			<xsl:call-template name="pi-generation">
				<xsl:with-param name="type" select="@type"/>
				<xsl:with-param name="pos" select="position()"/>
				<xsl:with-param name="depth" select="$depth"/>
			</xsl:call-template>
		</xsl:if>
	</xsl:if>
</xsl:template>

<xsl:template match="level_product">
	<tr>
		<td width="25%" class="topleft">
			<xsl:value-of select="@name"/><br/>
			<xsl:apply-templates select="/pim/documents/document">
				<xsl:with-param name="depth">0</xsl:with-param>
				<xsl:with-param name="level" select="@level_id"/>
			</xsl:apply-templates>
		</td>
		<td width="75%">
			<table width="100%" class="panel" cellspacing="0" cellpadding="0">
				<xsl:apply-templates select="level_form"/>
			</table>
		</td>
	</tr>
</xsl:template>

<xsl:template match="level_form">
	<tr>
		<td width="33%" class="topleft">
			<xsl:value-of select="@name"/><br/>
			<xsl:apply-templates select="/pim/documents/document">
				<xsl:with-param name="depth">1</xsl:with-param>
				<xsl:with-param name="level" select="@level_id"/>
			</xsl:apply-templates>
		</td>
		<td width="67%">
			<table width="100%" class="panel" cellspacing="0" cellpadding="0">
				<xsl:apply-templates select="level_strength"/>
			</table>
		</td>
	</tr>
</xsl:template>

<xsl:template match="level_strength">
	<tr>
		<td width="50%" class="topleft">
			<xsl:value-of select="@name"/><br/>
			<xsl:apply-templates select="/pim/documents/document">
				<xsl:with-param name="depth">2</xsl:with-param>
				<xsl:with-param name="level" select="@level_id"/>
			</xsl:apply-templates>
		</td>
		<td width="50%">
			<table width="100%" class="panel" cellspacing="0" cellpadding="0">
				<xsl:apply-templates select="level_presentation"/>
			</table>
		</td>
	</tr>
</xsl:template>

<xsl:template match="level_presentation">
	<tr>
		<td width="100%" class="topsides">
			<xsl:value-of select="@name"/><br/>
			<xsl:apply-templates select="/pim/documents/document">
				<xsl:with-param name="depth">3</xsl:with-param>
				<xsl:with-param name="level" select="@level_id"/>
			</xsl:apply-templates>
			<xsl:apply-templates select="level_outer | level_blister | level_immed"/>
			<xsl:apply-templates select="external_information"/>
		</td>
	</tr>
</xsl:template>

<xsl:template match="level_outer | level_blister | level_immed">
	<xsl:apply-templates select="/pim/documents/document">
		<xsl:with-param name="depth">4</xsl:with-param>
		<xsl:with-param name="level" select="@level_id"/>
	</xsl:apply-templates>
</xsl:template>

<xsl:template name="showlang">
	<xsl:param name="lang"/>

	<xsl:choose>
		<xsl:when test="$lang='cs'">Czech</xsl:when>
		<xsl:when test="$lang='da'">Danish</xsl:when>
		<xsl:when test="$lang='de'">German</xsl:when>
		<xsl:when test="$lang='el'">Greek</xsl:when>
		<xsl:when test="$lang='en'">English</xsl:when>
		<xsl:when test="$lang='es'">Spanish</xsl:when>
		<xsl:when test="$lang='et'">Estonian</xsl:when>
		<xsl:when test="$lang='fi'">Finnish</xsl:when>
		<xsl:when test="$lang='fr'">French</xsl:when>
		<xsl:when test="$lang='hu'">Hungarian</xsl:when>
		<xsl:when test="$lang='is'">Icelandic</xsl:when>
		<xsl:when test="$lang='it'">Italian</xsl:when>
		<xsl:when test="$lang='lt'">Lithuanian</xsl:when>
		<xsl:when test="$lang='lv'">Latvian</xsl:when>
		<xsl:when test="$lang='mt'">Maltese</xsl:when>
		<xsl:when test="$lang='nl'">Dutch</xsl:when>
		<xsl:when test="$lang='no'">Norwegian</xsl:when>		
		<xsl:when test="$lang='pl'">Polish</xsl:when>
		<xsl:when test="$lang='pt'">Portuguese</xsl:when>
		<xsl:when test="$lang='sk'">Slovak</xsl:when>
		<xsl:when test="$lang='sl'">Slovenian</xsl:when>
		<xsl:when test="$lang='sv'">Swedish</xsl:when>
		<xsl:otherwise><xsl:value-of select="$lang"/></xsl:otherwise>
	</xsl:choose>

</xsl:template>

<xsl:template match="multilang">
	<a>
		<xsl:attribute name="href">
			javascript:setlang('<xsl:value-of select="@lang"/>')
		</xsl:attribute>
		<xsl:attribute name="title">
			<xsl:call-template name="showlang">
				<xsl:with-param name="lang" select="./@lang"/>
			</xsl:call-template>
		</xsl:attribute>
		<span class="unchecked">
			<xsl:attribute name="id">lang-<xsl:value-of select="@lang"/></xsl:attribute>
			<xsl:value-of select="@lang"/>
		</span>
	</a>
	<xsl:if test="position() = 1"><script>setlang('<xsl:value-of select="@lang"/>')</script></xsl:if>
	<xsl:if test="position() != last()"><xsl:text> | </xsl:text></xsl:if>
</xsl:template>

<xsl:template match="external_information">
	<xsl:if test="position()=1"><xsl:text> </xsl:text></xsl:if>
	<a target="new">
		<xsl:attribute name="href"><xsl:value-of select="doc-leaf/@ref-file"/></xsl:attribute>
		<img src="util/style/file.gif" border="0">
			<xsl:attribute name="alt">
				<xsl:value-of select="doc-leaf/@title"/>
			</xsl:attribute>
		</img>
	</a>
</xsl:template>

</xsl:stylesheet>