<?xml version="1.0" encoding="utf-8"?>

<!-- 
	Version 2.6
	24 March 2006

	Author:
		Laurent Desqueper
-->

<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:ectd="http://www.ich.org/ectd" 
	xmlns:xlink="http://www.w3c.org/1999/xlink">

<!-- include combination and layout style sheets -->
<xsl:include href="common.xsl"/>
<xsl:include href="combined.xsl"/>
<xsl:include href="layout.xsl"/>

<!-- style sheet parameters -->
<xsl:param name="docpos"/>			<!-- The position of the PI to generate in the document zone -->
<xsl:param name="depth"/>			<!-- The level where the generate the PI as Integer: prd(0), frm(1), str(2), prs(3) -->
<xsl:param name="lang"/>				<!-- The language of the PI document to generate -->
<xsl:param name="caller"/>			<!-- The caller of the stylesheet : if empty, caller is the PIM Viewer -->
<xsl:param name="section"/>			<!-- The section to display : if empty, all document displays -->

<!-- style sheet version number -->
<xsl:param name="xsl-ver">2.6</xsl:param>

<!-- set output type to XHTML -->
<xsl:output indent="yes" method="xml"/>

<!-- structure of the document -->
<xsl:template match="/">
<html>
	<head>
		<title>
			<xsl:call-template name="getHeadingText"><xsl:with-param name="id">anx3</xsl:with-param></xsl:call-template>
			-
			<xsl:call-template name="getHeadingText"><xsl:with-param name="id">anx3_title</xsl:with-param></xsl:call-template>
		</title>
		<link href="util/style/doc.css" rel="stylesheet"/>
	</head>
	<body background="util/style/watermark.gif">
		<xsl:if test="$section =''">
																																																	<!-- COMMENTS -->
			<xsl:if test="count(/pim/documents/document[position() = $docpos]/comment[string-length(@section) = 0 and @lang=$lang]) > 0">
				<b><u>Comment on <xsl:call-template name="getDocumentType"/>:</u></b>
				<ul>
					<xsl:apply-templates select="/pim/documents/document[position() = $docpos]/comment[string-length(@section) = 0 and @lang=$lang]" mode="doc"/>
				</ul>
			</xsl:if>
		</xsl:if>
		<br/>
		<table cellpadding="1" cellspacing="0" width="100%" style="color:black">
			<xsl:if test="$section = ''">
																																																	<!-- TOP -->
				<tr>
					<xsl:if test="$caller = 'pimrs'">
						<td><xsl:text> </xsl:text></td>
					</xsl:if>
					<td width="100%" class="label">
						<xsl:call-template name="getHeadingText">
							<xsl:with-param name="id">immed_title</xsl:with-param>
						</xsl:call-template>
						<xsl:variable name="nature-i">
							<xsl:call-template name="displayElement">
								<xsl:with-param name="level">4</xsl:with-param>
								<xsl:with-param name="element">nature_i</xsl:with-param>
								<xsl:with-param name="mode">text</xsl:with-param>
							</xsl:call-template>
						</xsl:variable>
						<xsl:if test="string-length($nature-i) > 0">
							<br/><br/>
							<xsl:call-template name="displayElement">
								<xsl:with-param name="level">4</xsl:with-param>
								<xsl:with-param name="element">nature_i</xsl:with-param>
								<xsl:with-param name="mode">text</xsl:with-param>
							</xsl:call-template>
						</xsl:if>
					</td>
				</tr>
				<xsl:call-template name="displaySeparator"/>
			</xsl:if>

			<xsl:call-template name="displaySeparator"/>

			<xsl:if test="$section = '' or $section = 'immed_1'">
																																																	<!-- SECTION 1 -->
				<xsl:call-template name="displayHeading">
					<xsl:with-param name="id">immed_1</xsl:with-param>
					<xsl:with-param name="secnr">1</xsl:with-param>
					<xsl:with-param name="class">label</xsl:with-param>
				</xsl:call-template>
				
				<xsl:variable name="level_id" select="/pim/documents/document[position() = $docpos]/pi-level[1]/@ref-id"/>
				<xsl:variable name="content" select="key('level_id', $level_id)//@content"/>
				
				<xsl:choose>
					<xsl:when test="$content != 'product'">
						<xsl:call-template name="displayElement">
							<xsl:with-param name="level">4</xsl:with-param>
							<xsl:with-param name="element">component_name_i</xsl:with-param>
						</xsl:call-template>
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="nameMedicinalProduct"/>
						<xsl:call-template name="displayElement">
							<xsl:with-param name="level">0</xsl:with-param>
							<xsl:with-param name="element">common_name_i</xsl:with-param>
						</xsl:call-template>
						<xsl:call-template name="displayElement">
							<xsl:with-param name="level">4</xsl:with-param>
							<xsl:with-param name="element">component_name_i</xsl:with-param>
						</xsl:call-template>
						<xsl:call-template name="displayElement">
							<xsl:with-param name="level">1</xsl:with-param>
							<xsl:with-param name="element">route_i</xsl:with-param>
						</xsl:call-template>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:if>

			<xsl:call-template name="displaySeparator"/>

			<xsl:if test="$section = '' or $section = 'immed_2'">
																																																	<!-- SECTION 2 -->
				<xsl:call-template name="displayHeading">
					<xsl:with-param name="id">immed_2</xsl:with-param>
					<xsl:with-param name="secnr">2</xsl:with-param>
					<xsl:with-param name="class">label</xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="displayElement">
					<xsl:with-param name="level">4</xsl:with-param>
					<xsl:with-param name="element">administration_i</xsl:with-param>
				</xsl:call-template>
			</xsl:if>

			<xsl:call-template name="displaySeparator"/>

			<xsl:if test="$section = '' or $section = 'immed_3'">
																																																	<!-- SECTION 3 -->
				<xsl:call-template name="displayHeading">
					<xsl:with-param name="id">immed_3</xsl:with-param>
					<xsl:with-param name="secnr">3</xsl:with-param>
					<xsl:with-param name="class">label</xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="displayElement">
					<xsl:with-param name="level">3</xsl:with-param>
					<xsl:with-param name="element">expiry_i</xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="displayElement">
					<xsl:with-param name="level">3</xsl:with-param>
					<xsl:with-param name="element">life_open_i</xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="displayElement">
					<xsl:with-param name="level">3</xsl:with-param>
					<xsl:with-param name="element">life_reconstituted_i</xsl:with-param>
				</xsl:call-template>
			</xsl:if>

			<xsl:call-template name="displaySeparator"/>

			<xsl:if test="$section = '' or $section = 'immed_4'">
																																																	<!-- SECTION 4 -->
				<xsl:call-template name="displayHeading">
					<xsl:with-param name="id">immed_4</xsl:with-param>
					<xsl:with-param name="secnr">4</xsl:with-param>
					<xsl:with-param name="class">label</xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="displayElement">
					<xsl:with-param name="level">2</xsl:with-param>
					<xsl:with-param name="element">batch</xsl:with-param>
				</xsl:call-template>
			</xsl:if>

			<xsl:call-template name="displaySeparator"/>

			<xsl:if test="$section = '' or $section = 'immed_5'">
																																																	<!-- SECTION 5 -->
				<xsl:call-template name="displayHeading">
					<xsl:with-param name="id">immed_5</xsl:with-param>
					<xsl:with-param name="secnr">5</xsl:with-param>
					<xsl:with-param name="class">label</xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="displayElement">
					<xsl:with-param name="level">4</xsl:with-param>
					<xsl:with-param name="element">pack_size_i</xsl:with-param>
				</xsl:call-template>
			</xsl:if>
			
			<xsl:call-template name="displaySeparator"/>

			<xsl:if test="$section = '' or $section = 'immed_6'">
																																																	<!-- SECTION 6 -->
				<xsl:call-template name="displayHeading">
					<xsl:with-param name="id">immed_6</xsl:with-param>
					<xsl:with-param name="secnr">6</xsl:with-param>
					<xsl:with-param name="class">label</xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="displayElement">
					<xsl:with-param name="level">4</xsl:with-param>
					<xsl:with-param name="element">other_information_i</xsl:with-param>
				</xsl:call-template>
			</xsl:if>
		</table>
		<br/><br/>
		<xsl:if test="$section ='' and $caller = ''">
																																																	<!-- FOOTNOTE -->
			<font size="-5">Blister Labelling style sheet version <xsl:value-of select="$xsl-ver"/></font>
		</xsl:if>
		<br/>
	</body>
</html>
</xsl:template>

<!-- Special case of Section 1: name of the medicinal product -->
<xsl:template name="nameMedicinalProduct">
	<xsl:variable name="nQualBeforeInv">
		<xsl:call-template name="countDifferentElement">
			<xsl:with-param name="level">3</xsl:with-param>
			<xsl:with-param name="element">qual_before_inv</xsl:with-param>
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="nQualAfterInv">
		<xsl:call-template name="countDifferentElement">
			<xsl:with-param name="level">3</xsl:with-param>
			<xsl:with-param name="element">qual_after_inv</xsl:with-param>
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="nStrength">
		<xsl:call-template name="countElement">
			<xsl:with-param name="level">2</xsl:with-param>
			<xsl:with-param name="element">strength</xsl:with-param>
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="nQualStrength">
		<xsl:call-template name="countDifferentElement">
			<xsl:with-param name="level">3</xsl:with-param>
			<xsl:with-param name="element">qual_strength</xsl:with-param>
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="nQualForm">
		<xsl:call-template name="countDifferentElement">
			<xsl:with-param name="level">3</xsl:with-param>
			<xsl:with-param name="element">qual_form_i</xsl:with-param>
		</xsl:call-template>
	</xsl:variable>
	
	<xsl:choose>
		<xsl:when test="contains($nQualBeforeInv, 'N') or contains($nQualAfterInv, 'N') or contains($nQualStrength, 'N') or contains($nQualForm, 'N')">
			<!-- The name of medicinal product is made of different qualifiers -->
			<xsl:choose>
				<xsl:when test="$nStrength > 1">
					<!-- The name of medicinal product contains several strengths -->
					<xsl:for-each select="/pim/documents/document[position() = $docpos]/pi-level">
						<xsl:variable name="level_id" select="@ref-id"/>
						<xsl:for-each select="key('level_id', $level_id)/ancestor-or-self::level_strength/strength">
							<xsl:variable name="str-pos" select="position()"/>
							<xsl:for-each select="key('level_id', $level_id)//level_presentation | key('level_id', $level_id)/ancestor::level_presentation">
								<tr>
									<xsl:if test="$caller = 'pimrs'">
										<td><xsl:text> </xsl:text></td>
									</xsl:if>
									<td width="100%">
										<xsl:for-each select="qual_before_inv/pi-group/pi-leaf">
											<xsl:call-template name="displayTemplateText">
												<xsl:with-param name="id" select="@ref-id"/>
											</xsl:call-template>
										</xsl:for-each>
										<xsl:for-each select="../../../invented_name/pi-group/pi-leaf">
											<xsl:call-template name="displayTemplateText">
												<xsl:with-param name="id" select="@ref-id"/>
											</xsl:call-template>
										</xsl:for-each>
										<xsl:for-each select="qual_after_inv/pi-group/pi-leaf">
											<xsl:call-template name="displayTemplateText">
												<xsl:with-param name="id" select="@ref-id"/>
											</xsl:call-template>
										</xsl:for-each>
										<xsl:for-each select="../strength[$str-pos]/pi-group/pi-leaf">
											<xsl:call-template name="displayTemplateText">
												<xsl:with-param name="id" select="@ref-id"/>
											</xsl:call-template>
										</xsl:for-each>
										<xsl:for-each select="qual_strength/pi-group/pi-leaf">
											<xsl:call-template name="displayTemplateText">
												<xsl:with-param name="id" select="@ref-id"/>
											</xsl:call-template>
										</xsl:for-each>
										<xsl:for-each select="../../form_inline_i/pi-group/pi-leaf">
											<xsl:call-template name="displayTemplateText">
												<xsl:with-param name="id" select="@ref-id"/>
											</xsl:call-template>
										</xsl:for-each>
										<xsl:for-each select="qual_form_i/pi-group/pi-leaf">
											<xsl:call-template name="displayTemplateText">
												<xsl:with-param name="id" select="@ref-id"/>
											</xsl:call-template>
										</xsl:for-each>
									</td>
								</tr>
							</xsl:for-each>
						</xsl:for-each>
					</xsl:for-each>
				</xsl:when>
				<xsl:otherwise>
					<!-- The name of medicinal product contains a single strength -->
					<xsl:for-each select="/pim/documents/document[position() = $docpos]/pi-level">
						<xsl:variable name="level_id" select="@ref-id"/>
						<xsl:for-each select="key('level_id', $level_id)//level_presentation | key('level_id', $level_id)/ancestor-or-self::level_presentation">
							<tr>
								<xsl:if test="$caller = 'pimrs'">
									<td><xsl:text> </xsl:text></td>
								</xsl:if>
								<td width="100%">
									<xsl:for-each select="qual_before_inv/pi-group/pi-leaf">
										<xsl:call-template name="displayTemplateText">
											<xsl:with-param name="id" select="@ref-id"/>
										</xsl:call-template>
									</xsl:for-each>
									<xsl:call-template name="displayElement">
										<xsl:with-param name="level">0</xsl:with-param>
										<xsl:with-param name="element">invented_name</xsl:with-param>
										<xsl:with-param name="mode">text</xsl:with-param>
									</xsl:call-template>
									<xsl:for-each select="qual_after_inv/pi-group/pi-leaf">
										<xsl:call-template name="displayTemplateText">
											<xsl:with-param name="id" select="@ref-id"/>
										</xsl:call-template>
									</xsl:for-each>
									<xsl:call-template name="displayElement">
										<xsl:with-param name="level">2</xsl:with-param>
										<xsl:with-param name="element">strength</xsl:with-param>
										<xsl:with-param name="mode">text</xsl:with-param>
									</xsl:call-template>
									<xsl:for-each select="qual_strength/pi-group/pi-leaf">
										<xsl:call-template name="displayTemplateText">
											<xsl:with-param name="id" select="@ref-id"/>
										</xsl:call-template>
									</xsl:for-each>
									<xsl:call-template name="displayElement">
										<xsl:with-param name="level">1</xsl:with-param>
										<xsl:with-param name="element">form_inline_i</xsl:with-param>
										<xsl:with-param name="mode">text</xsl:with-param>
									</xsl:call-template>
									<xsl:for-each select="qual_form_i/pi-group/pi-leaf">
										<xsl:call-template name="displayTemplateText">
											<xsl:with-param name="id" select="@ref-id"/>
										</xsl:call-template>
									</xsl:for-each>
								</td>
							</tr>
						</xsl:for-each>
					</xsl:for-each>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:when>
		<xsl:otherwise>
			<!-- The name of medicinal product is made of identical qualifiers -->
			<xsl:choose>
				<xsl:when test="$nStrength > 1">
					<!-- The name of medicinal product contains several strengths -->
					<xsl:for-each select="/pim/documents/document[position() = $docpos]/pi-level[1]">
						<xsl:variable name="level_id" select="@ref-id"/>
						<xsl:for-each select="key('level_id', $level_id)/ancestor-or-self::level_strength/strength">
							<xsl:variable name="str-pos" select="position()"/>
							<xsl:for-each select="key('level_id', $level_id)">
								<tr>
									<xsl:if test="$caller = 'pimrs'">
										<td><xsl:text> </xsl:text></td>
									</xsl:if>
									<td width="100%">
										<xsl:call-template name="displayElement">
											<xsl:with-param name="level">3</xsl:with-param>
											<xsl:with-param name="element">qual_before_inv</xsl:with-param>
											<xsl:with-param name="mode">text</xsl:with-param>
										</xsl:call-template>
										<xsl:call-template name="displayElement">
											<xsl:with-param name="level">0</xsl:with-param>
											<xsl:with-param name="element">invented_name</xsl:with-param>
											<xsl:with-param name="mode">text</xsl:with-param>
										</xsl:call-template>
										<xsl:call-template name="displayElement">
											<xsl:with-param name="level">3</xsl:with-param>
											<xsl:with-param name="element">qual_after_inv</xsl:with-param>
											<xsl:with-param name="mode">text</xsl:with-param>
										</xsl:call-template>
										<xsl:for-each select="key('level_id', $level_id)/ancestor-or-self::level_strength/strength[$str-pos]/pi-group/pi-leaf">
											<xsl:call-template name="displayTemplateText">
												<xsl:with-param name="id" select="@ref-id"/>
											</xsl:call-template>
										</xsl:for-each>
										<xsl:call-template name="displayElement">
											<xsl:with-param name="level">3</xsl:with-param>
											<xsl:with-param name="element">qual_strength</xsl:with-param>
											<xsl:with-param name="mode">text</xsl:with-param>
										</xsl:call-template>
										<xsl:call-template name="displayElement">
											<xsl:with-param name="level">1</xsl:with-param>
											<xsl:with-param name="element">form_inline_i</xsl:with-param>
											<xsl:with-param name="mode">text</xsl:with-param>
										</xsl:call-template>
										<xsl:call-template name="displayElement">
											<xsl:with-param name="level">3</xsl:with-param>
											<xsl:with-param name="element">qual_form_i</xsl:with-param>
											<xsl:with-param name="mode">text</xsl:with-param>
										</xsl:call-template>
									</td>
								</tr>
							</xsl:for-each>
						</xsl:for-each>
					</xsl:for-each>
				</xsl:when>
				<xsl:otherwise>
					<!-- The name of medicinal product contains a single strength -->
					<tr>
						<xsl:if test="$caller = 'pimrs'">
							<td><xsl:text> </xsl:text></td>
						</xsl:if>
						<td width="100%">
							<xsl:call-template name="displayElement">
								<xsl:with-param name="level">3</xsl:with-param>
								<xsl:with-param name="element">qual_before_inv</xsl:with-param>
								<xsl:with-param name="mode">text</xsl:with-param>
							</xsl:call-template>
							<xsl:call-template name="displayElement">
								<xsl:with-param name="level">0</xsl:with-param>
								<xsl:with-param name="element">invented_name</xsl:with-param>
								<xsl:with-param name="mode">text</xsl:with-param>
							</xsl:call-template>
							<xsl:call-template name="displayElement">
								<xsl:with-param name="level">3</xsl:with-param>
								<xsl:with-param name="element">qual_after_inv</xsl:with-param>
								<xsl:with-param name="mode">text</xsl:with-param>
							</xsl:call-template>
							<xsl:call-template name="displayElement">
								<xsl:with-param name="level">2</xsl:with-param>
								<xsl:with-param name="element">strength</xsl:with-param>
								<xsl:with-param name="mode">text</xsl:with-param>
							</xsl:call-template>
							<xsl:call-template name="displayElement">
								<xsl:with-param name="level">3</xsl:with-param>
								<xsl:with-param name="element">qual_strength</xsl:with-param>
								<xsl:with-param name="mode">text</xsl:with-param>
							</xsl:call-template>
							<xsl:call-template name="displayElement">
								<xsl:with-param name="level">1</xsl:with-param>
								<xsl:with-param name="element">form_inline_i</xsl:with-param>
								<xsl:with-param name="mode">text</xsl:with-param>
							</xsl:call-template>
							<xsl:call-template name="displayElement">
								<xsl:with-param name="level">3</xsl:with-param>
								<xsl:with-param name="element">qual_form_i</xsl:with-param>
								<xsl:with-param name="mode">text</xsl:with-param>
							</xsl:call-template>
						</td>
					</tr>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

</xsl:stylesheet>