<?xml version="1.0" encoding="utf-8"?>

<!-- 
	Version 2.6
	24 March 2006

	Author:
		Laurent Desqueper
-->

<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:ectd="http://www.ich.org/ectd" 
	xmlns:xlink="http://www.w3c.org/1999/xlink">

<!-- include combination and layout style sheets -->
<xsl:include href="common.xsl"/>
<xsl:include href="combined.xsl"/>
<xsl:include href="layout.xsl"/>

<!-- style sheet parameters -->
<xsl:param name="docpos"/>			<!-- The position of the PI to generate in the document zone -->
<xsl:param name="depth"/>			<!-- The level where the generate the PI as Integer: prd(0), frm(1), str(2), prs(3) -->
<xsl:param name="lang"/>				<!-- The language of the PI document to generate -->
<xsl:param name="caller"/>			<!-- The caller of the stylesheet : if empty, caller is the PIM Viewer -->
<xsl:param name="section"/>			<!-- The section to display : if empty, all document displays -->

<!-- style sheet version number -->
<xsl:param name="xsl-ver">2.6</xsl:param>

<!-- set output type to XHTML -->
<xsl:output indent="yes" method="xml"/>

<!-- structure of the document -->
<xsl:template match="/">
<html>
	<head>
		<title>
			<xsl:call-template name="getHeadingText"><xsl:with-param name="id">anx3</xsl:with-param></xsl:call-template>
			-
			<xsl:call-template name="getHeadingText"><xsl:with-param name="id">head_pack_subtitle</xsl:with-param></xsl:call-template>
		</title>
		<link href="util/style/doc.css" rel="stylesheet"/>
	</head>
	<body background="util/style/watermark.gif">
		<xsl:if test="$section =''">
																																																	<!-- COMMENTS -->
			<xsl:if test="count(/pim/documents/document[position() = $docpos]/comment[string-length(@section) = 0 and @lang=$lang]) > 0">
				<b><u>Comment on <xsl:call-template name="getDocumentType"/>:</u></b>
				<ul>
					<xsl:apply-templates select="/pim/documents/document[position() = $docpos]/comment[string-length(@section) = 0 and @lang=$lang]" mode="doc"/>
				</ul>
			</xsl:if>
																																																	<!-- TITLE -->
			<center class="page-break">			
				<h1>
					<br style="line-height: 98mm"/>
					<xsl:call-template name="getHeadingText"><xsl:with-param name="id">head_pack_title</xsl:with-param></xsl:call-template>
				</h1>
				<br style="line-height: 30mm"/>
			</center>
			<center>
				<h1>
					<xsl:call-template name="getHeadingText"><xsl:with-param name="id">head_pack_subtitle</xsl:with-param></xsl:call-template>
				</h1>
			</center>
		</xsl:if>
		
		<xsl:variable name="level_id" select="/pim/documents/document[position() = $docpos]/pi-level[1]/@ref-id"/>
		<xsl:variable name="modeAdmin" select="key('level_id', $level_id)//level_outer[1]/../../../mode_administration/@verb"/>
		
		<table cellpadding="1" cellspacing="0" width="100%" style="color:black">
			<xsl:if test="$section = ''">
																																																<!-- TOP -->
				<xsl:call-template name="displaySeparator"/>
				<xsl:call-template name="nameMedicinalProduct"/>
				<xsl:call-template name="commonNameSubstance"/>
				
				<xsl:call-template name="displaySeparator"/>
				<xsl:call-template name="displaySeparator"/>
			
																																																<!-- OTC-POM BOX -->
				<xsl:call-template name="boxOtcPom"/>

				<xsl:call-template name="displaySeparator"/>
				<xsl:call-template name="displaySeparator"/>
																																																<!-- IN THIS LEAFLET -->
				<xsl:call-template name="displaySubHeading">
					<xsl:with-param name="id">head_pack_itl</xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="displayTocHeading">
					<xsl:with-param name="id">head_pack_itl_1</xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="displayTocHeading">
					<xsl:with-param name="id">head_pack_itl_2_<xsl:value-of select="$modeAdmin"/></xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="displayTocHeading">
					<xsl:with-param name="id">head_pack_itl_3_<xsl:value-of select="$modeAdmin"/></xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="displayTocHeading">
					<xsl:with-param name="id">head_pack_itl_4</xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="displayTocHeading">
					<xsl:with-param name="id">head_pack_itl_5</xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="displayTocHeading">
					<xsl:with-param name="id">head_pack_itl_6</xsl:with-param>
				</xsl:call-template>

				<xsl:call-template name="displaySeparator"/>
				<xsl:call-template name="displaySeparator"/>
			</xsl:if>

			<xsl:if test="$section ='' or substring($section, 1, 11) = 'head_pack_1'">
				<xsl:if test="$section = '' or $section = 'head_pack_1'">
																																																<!-- SECTION 1 -->
					<xsl:call-template name="displayHeading">
						<xsl:with-param name="id">head_pack_1</xsl:with-param>
						<xsl:with-param name="secnr">1</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="displayElement">
						<xsl:with-param name="level">2</xsl:with-param>
						<xsl:with-param name="element">indication_p</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="displaySeparator"/>
					<xsl:call-template name="displaySeparator"/>
				</xsl:if>
			</xsl:if>

			<xsl:if test="$section ='' or substring($section, 1, 11) = 'head_pack_2'">
				<xsl:if test="$section = '' or $section = 'head_pack_2'">
																																																<!-- SECTION 2 -->
					<xsl:call-template name="displayHeading">
						<xsl:with-param name="id">head_pack_2_<xsl:value-of select="$modeAdmin"/></xsl:with-param>
						<xsl:with-param name="secnr">2</xsl:with-param>
					</xsl:call-template>
				</xsl:if>
					
				<xsl:if test="$section = '' or $section = 'head_pack_2' or $section = 'head_pack_2a'">
																																															<!-- SECTION 2 a -->
					<xsl:variable name="nContent2a">
						<xsl:call-template name="countElement">
							<xsl:with-param name="level">2</xsl:with-param>
							<xsl:with-param name="element">contraindication_p</xsl:with-param>
						</xsl:call-template>
					</xsl:variable>
					<xsl:if test="$nContent2a > 0">
						<xsl:call-template name="displaySubHeading">
							<xsl:with-param name="id">head_pack_2a_<xsl:value-of select="$modeAdmin"/></xsl:with-param>
							<xsl:with-param name="secnr">2a</xsl:with-param>
						</xsl:call-template>
						<xsl:call-template name="displayElement">
							<xsl:with-param name="level">2</xsl:with-param>
							<xsl:with-param name="element">contraindication_p</xsl:with-param>
						</xsl:call-template>
						<xsl:call-template name="displaySeparator"/>
					</xsl:if>
				</xsl:if>
				
				<xsl:if test="$section = '' or $section = 'head_pack_2' or $section = 'head_pack_2a_add'">
																																															<!-- SECTION 2 a add -->
					<xsl:variable name="nAdditional2a">
						<xsl:call-template name="countElementWithLocation">
							<xsl:with-param name="level">3</xsl:with-param>
							<xsl:with-param name="element">additional_section2_p</xsl:with-param>
							<xsl:with-param name="location">before-warning</xsl:with-param>
						</xsl:call-template>
					</xsl:variable>
					<xsl:if test="$nAdditional2a > 0">
						<xsl:call-template name="displayElementWithLocation">
							<xsl:with-param name="level">3</xsl:with-param>
							<xsl:with-param name="element">additional_section2_p</xsl:with-param>
							<xsl:with-param name="location">before-warning</xsl:with-param>
						</xsl:call-template>
						<xsl:call-template name="displaySeparator"/>
					</xsl:if>
				</xsl:if>

				<xsl:if test="$section = '' or $section = 'head_pack_2' or $section = 'head_pack_2b'">
																																															<!-- SECTION 2 b -->
					<xsl:variable name="nContent2b">
						<xsl:call-template name="countElement">
							<xsl:with-param name="level">3</xsl:with-param>
							<xsl:with-param name="element">warning_p</xsl:with-param>
						</xsl:call-template>
					</xsl:variable>
					<xsl:if test="$nContent2b > 0">
						<xsl:call-template name="displaySubHeading">
							<xsl:with-param name="id">head_pack_2b_<xsl:value-of select="$modeAdmin"/></xsl:with-param>
							<xsl:with-param name="secnr">2b</xsl:with-param>
						</xsl:call-template>
						<xsl:call-template name="displayElement">
							<xsl:with-param name="level">3</xsl:with-param>
							<xsl:with-param name="element">warning_p</xsl:with-param>
						</xsl:call-template>
						<xsl:call-template name="displaySeparator"/>
					</xsl:if>
				</xsl:if>
				
				<xsl:if test="$section = '' or $section = 'head_pack_2' or $section = 'head_pack_2b_add'">
																																															<!-- SECTION 2 b add -->
					<xsl:variable name="nAdditional2b">
						<xsl:call-template name="countElementWithLocation">
							<xsl:with-param name="level">3</xsl:with-param>
							<xsl:with-param name="element">additional_section2_p</xsl:with-param>
							<xsl:with-param name="location">before-interaction-medical</xsl:with-param>
						</xsl:call-template>
					</xsl:variable>
					<xsl:if test="$nAdditional2b > 0">
						<xsl:call-template name="displayElementWithLocation">
							<xsl:with-param name="level">3</xsl:with-param>
							<xsl:with-param name="element">additional_section2_p</xsl:with-param>
							<xsl:with-param name="location">before-interaction-medical</xsl:with-param>
						</xsl:call-template>
						<xsl:call-template name="displaySeparator"/>
					</xsl:if>
				</xsl:if>
				
				<xsl:if test="$section = '' or $section = 'head_pack_2' or $section = 'head_pack_2c'">
																																															<!-- SECTION 2 c -->
					<xsl:variable name="nContent2c">
						<xsl:call-template name="countElement">
							<xsl:with-param name="level">1</xsl:with-param>
							<xsl:with-param name="element">interaction_medical_p</xsl:with-param>
						</xsl:call-template>
					</xsl:variable>
					<xsl:if test="$nContent2c > 0">
						<xsl:call-template name="displaySubHeading">
							<xsl:with-param name="id">head_pack_2c_<xsl:value-of select="$modeAdmin"/></xsl:with-param>
							<xsl:with-param name="secnr">2c</xsl:with-param>
						</xsl:call-template>
						<xsl:call-template name="displayElement">
							<xsl:with-param name="level">1</xsl:with-param>
							<xsl:with-param name="element">interaction_medical_p</xsl:with-param>
						</xsl:call-template>
						<xsl:call-template name="displaySeparator"/>
					</xsl:if>
				</xsl:if>
				
				<xsl:if test="$section = '' or $section = 'head_pack_2' or $section = 'head_pack_2c_add'">
																																															<!-- SECTION 2 c add -->
					<xsl:variable name="nAdditional2c">
						<xsl:call-template name="countElementWithLocation">
							<xsl:with-param name="level">3</xsl:with-param>
							<xsl:with-param name="element">additional_section2_p</xsl:with-param>
							<xsl:with-param name="location">before-interaction-food</xsl:with-param>
						</xsl:call-template>
					</xsl:variable>
					<xsl:if test="$nAdditional2c > 0">
						<xsl:call-template name="displayElementWithLocation">
							<xsl:with-param name="level">3</xsl:with-param>
							<xsl:with-param name="element">additional_section2_p</xsl:with-param>
							<xsl:with-param name="location">before-interaction-food</xsl:with-param>
						</xsl:call-template>
						<xsl:call-template name="displaySeparator"/>
					</xsl:if>
				</xsl:if>
				
				<xsl:if test="$section = '' or $section = 'head_pack_2' or $section = 'head_pack_2d'">
																																															<!-- SECTION 2 d -->
					<xsl:variable name="nContent2d">
						<xsl:call-template name="countElement">
							<xsl:with-param name="level">1</xsl:with-param>
							<xsl:with-param name="element">interaction_food_p</xsl:with-param>
						</xsl:call-template>
					</xsl:variable>
					<xsl:if test="$nContent2d > 0">
						<xsl:call-template name="displaySubHeading">
							<xsl:with-param name="id">head_pack_2d_<xsl:value-of select="$modeAdmin"/></xsl:with-param>
							<xsl:with-param name="secnr">2d</xsl:with-param>
						</xsl:call-template>
						<xsl:call-template name="displayElement">
							<xsl:with-param name="level">1</xsl:with-param>
							<xsl:with-param name="element">interaction_food_p</xsl:with-param>
						</xsl:call-template>
						<xsl:call-template name="displaySeparator"/>
					</xsl:if>
				</xsl:if>
				
				<xsl:if test="$section = '' or $section = 'head_pack_2' or $section = 'head_pack_2d_add'">
																																															<!-- SECTION 2 d add -->
					<xsl:variable name="nAdditional2d">
						<xsl:call-template name="countElementWithLocation">
							<xsl:with-param name="level">3</xsl:with-param>
							<xsl:with-param name="element">additional_section2_p</xsl:with-param>
							<xsl:with-param name="location">before-pregnancy</xsl:with-param>
						</xsl:call-template>
					</xsl:variable>
					
					<xsl:if test="$nAdditional2d > 0">
						<xsl:call-template name="displayElementWithLocation">
							<xsl:with-param name="level">3</xsl:with-param>
							<xsl:with-param name="element">additional_section2_p</xsl:with-param>
							<xsl:with-param name="location">before-pregnancy</xsl:with-param>
						</xsl:call-template>
						<xsl:call-template name="displaySeparator"/>
					</xsl:if>
				</xsl:if>
				
				<xsl:if test="$section = '' or $section = 'head_pack_2' or $section = 'head_pack_2e'">
																																															<!-- SECTION 2 e -->
					<xsl:variable name="nContent2e">
						<xsl:call-template name="countElement">
							<xsl:with-param name="level">1</xsl:with-param>
							<xsl:with-param name="element">pregnancy_p</xsl:with-param>
						</xsl:call-template>
					</xsl:variable>
					<xsl:if test="$nContent2e > 0">
						<xsl:call-template name="displaySubHeading">
							<xsl:with-param name="id">head_pack_2e</xsl:with-param>
							<xsl:with-param name="secnr">2e</xsl:with-param>
						</xsl:call-template>
						<xsl:call-template name="displayElement">
							<xsl:with-param name="level">1</xsl:with-param>
							<xsl:with-param name="element">pregnancy_p</xsl:with-param>
						</xsl:call-template>
						<xsl:call-template name="displaySeparator"/>
					</xsl:if>
				</xsl:if>
				
				<xsl:if test="$section = '' or $section = 'head_pack_2' or $section = 'head_pack_2e_add'">
																																															<!-- SECTION 2 e add -->
					<xsl:variable name="nAdditional2e">
						<xsl:call-template name="countElementWithLocation">
							<xsl:with-param name="level">3</xsl:with-param>
							<xsl:with-param name="element">additional_section2_p</xsl:with-param>
							<xsl:with-param name="location">before-breastfeeding</xsl:with-param>
						</xsl:call-template>
					</xsl:variable>
					
					<xsl:if test="$nAdditional2e > 0">
						<xsl:call-template name="displayElementWithLocation">
							<xsl:with-param name="level">3</xsl:with-param>
							<xsl:with-param name="element">additional_section2_p</xsl:with-param>
							<xsl:with-param name="location">before-breastfeeding</xsl:with-param>
						</xsl:call-template>
						<xsl:call-template name="displaySeparator"/>
					</xsl:if>
				</xsl:if>
				
				<xsl:if test="$section = '' or $section = 'head_pack_2' or $section = 'head_pack_2f'">
																																															<!-- SECTION 2 f -->
					<xsl:variable name="nContent2f">
						<xsl:call-template name="countElement">
							<xsl:with-param name="level">1</xsl:with-param>
							<xsl:with-param name="element">breastfeeding_p</xsl:with-param>
						</xsl:call-template>
					</xsl:variable>
					<xsl:if test="$nContent2f > 0">
						<xsl:call-template name="displaySubHeading">
							<xsl:with-param name="id">head_pack_2f</xsl:with-param>
							<xsl:with-param name="secnr">2f</xsl:with-param>
						</xsl:call-template>
						<xsl:call-template name="displayElement">
							<xsl:with-param name="level">1</xsl:with-param>
							<xsl:with-param name="element">breastfeeding_p</xsl:with-param>
						</xsl:call-template>
						<xsl:call-template name="displaySeparator"/>
					</xsl:if>
				</xsl:if>
				
				<xsl:if test="$section = '' or $section = 'head_pack_2' or $section = 'head_pack_2g'">
																																															<!-- SECTION 2 g -->
					<xsl:variable name="nContent2g">
						<xsl:call-template name="countElement">
							<xsl:with-param name="level">1</xsl:with-param>
							<xsl:with-param name="element">pregnancy_breastfeeding_p</xsl:with-param>
						</xsl:call-template>
					</xsl:variable>
					<xsl:if test="$nContent2g > 0">
						<xsl:call-template name="displaySubHeading">
							<xsl:with-param name="id">head_pack_2g</xsl:with-param>
							<xsl:with-param name="secnr">2g</xsl:with-param>
						</xsl:call-template>
						<xsl:call-template name="displayElement">
							<xsl:with-param name="level">1</xsl:with-param>
							<xsl:with-param name="element">pregnancy_breastfeeding_p</xsl:with-param>
						</xsl:call-template>
						<xsl:call-template name="displaySeparator"/>
					</xsl:if>
				</xsl:if>
				
				<xsl:if test="$section = '' or $section = 'head_pack_2' or $section = 'head_pack_2g_add'">
																																															<!-- SECTION 2 g add -->
					<xsl:variable name="nAdditional2g">
						<xsl:call-template name="countElementWithLocation">
							<xsl:with-param name="level">3</xsl:with-param>
							<xsl:with-param name="element">additional_section2_p</xsl:with-param>
							<xsl:with-param name="location">before-driving-info</xsl:with-param>
						</xsl:call-template>
					</xsl:variable>
					
					<xsl:if test="$nAdditional2g > 0">
						<xsl:call-template name="displayElementWithLocation">
							<xsl:with-param name="level">3</xsl:with-param>
							<xsl:with-param name="element">additional_section2_p</xsl:with-param>
							<xsl:with-param name="location">before-driving-info</xsl:with-param>
						</xsl:call-template>
						<xsl:call-template name="displaySeparator"/>
					</xsl:if>
				</xsl:if>
				
				<xsl:if test="$section = '' or $section = 'head_pack_2' or $section = 'head_pack_2h'">
																																															<!-- SECTION 2 h -->
					<xsl:variable name="nContent2h">
						<xsl:call-template name="countElement">
							<xsl:with-param name="level">1</xsl:with-param>
							<xsl:with-param name="element">driving_p</xsl:with-param>
						</xsl:call-template>
					</xsl:variable>
					<xsl:if test="$nContent2h > 0">
						<xsl:call-template name="displaySubHeading">
							<xsl:with-param name="id">head_pack_2h</xsl:with-param>
							<xsl:with-param name="secnr">2h</xsl:with-param>
						</xsl:call-template>
						<xsl:call-template name="displayElement">
							<xsl:with-param name="level">1</xsl:with-param>
							<xsl:with-param name="element">driving_p</xsl:with-param>
						</xsl:call-template>
						<xsl:call-template name="displaySeparator"/>
					</xsl:if>
				</xsl:if>
				
				<xsl:if test="$section = '' or $section = 'head_pack_2' or $section = 'head_pack_2h_add'">
																																															<!-- SECTION 2 h add -->
					<xsl:variable name="nAdditional2h">
						<xsl:call-template name="countElementWithLocation">
							<xsl:with-param name="level">3</xsl:with-param>
							<xsl:with-param name="element">additional_section2_p</xsl:with-param>
							<xsl:with-param name="location">before-excipient-info</xsl:with-param>
						</xsl:call-template>
					</xsl:variable>
					
					<xsl:if test="$nAdditional2h > 0">
						<xsl:call-template name="displayElementWithLocation">
							<xsl:with-param name="level">3</xsl:with-param>
							<xsl:with-param name="element">additional_section2_p</xsl:with-param>
							<xsl:with-param name="location">before-excipient-info</xsl:with-param>
						</xsl:call-template>
						<xsl:call-template name="displaySeparator"/>
					</xsl:if>
				</xsl:if>
				
				<xsl:if test="$section = '' or $section = 'head_pack_2' or $section = 'head_pack_2i'">
																																															<!-- SECTION 2 i -->
					<xsl:variable name="nContent2i">
						<xsl:call-template name="countElement">
							<xsl:with-param name="level">2</xsl:with-param>
							<xsl:with-param name="element">excipient_main_p</xsl:with-param>
						</xsl:call-template>
					</xsl:variable>
					<xsl:if test="$nContent2i > 0">
						<xsl:call-template name="displaySubHeading">
							<xsl:with-param name="id">head_pack_2i</xsl:with-param>
							<xsl:with-param name="secnr">2i</xsl:with-param>
						</xsl:call-template>
						<xsl:call-template name="displayElement">
							<xsl:with-param name="level">2</xsl:with-param>
							<xsl:with-param name="element">excipient_main_p</xsl:with-param>
						</xsl:call-template>
						<xsl:call-template name="displaySeparator"/>
					</xsl:if>
				</xsl:if>
				
				<xsl:if test="$section = '' or $section = 'head_pack_2' or $section = 'head_pack_2i_add'">
																																															<!-- SECTION 2 i add -->
					<xsl:variable name="nAdditional2i">
						<xsl:call-template name="countElementWithLocation">
							<xsl:with-param name="level">3</xsl:with-param>
							<xsl:with-param name="element">additional_section2_p</xsl:with-param>
							<xsl:with-param name="location">end</xsl:with-param>
						</xsl:call-template>
					</xsl:variable>
					
					<xsl:if test="$nAdditional2i > 0">
						<xsl:call-template name="displayElementWithLocation">
							<xsl:with-param name="level">3</xsl:with-param>
							<xsl:with-param name="element">additional_section2_p</xsl:with-param>
							<xsl:with-param name="location">end</xsl:with-param>
						</xsl:call-template>
						<xsl:call-template name="displaySeparator"/>
					</xsl:if>
				</xsl:if>
			</xsl:if>
			
			<xsl:call-template name="displaySeparator"/>
			
			<xsl:if test="$section ='' or substring($section, 1, 11) = 'head_pack_3'">
				<xsl:if test="$section = '' or $section = 'head_pack_3'">
																																																<!-- SECTION 3 -->
					<xsl:call-template name="displayHeading">
						<xsl:with-param name="id">head_pack_3_<xsl:value-of select="$modeAdmin"/></xsl:with-param>
						<xsl:with-param name="secnr">3</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="displayElement">
						<xsl:with-param name="level">3</xsl:with-param>
						<xsl:with-param name="element">instruction_for_proper_use_p</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="displaySeparator"/>
				</xsl:if>
					
				<xsl:if test="$section = '' or $section = 'head_pack_3' or $section = 'head_pack_3a'">
																																															<!-- SECTION 3 a -->
					<xsl:variable name="nContent3a">
						<xsl:call-template name="countElement">
							<xsl:with-param name="level">1</xsl:with-param>
							<xsl:with-param name="element">overdose_p</xsl:with-param>
						</xsl:call-template>
					</xsl:variable>
					<xsl:if test="$nContent3a > 0">
						<xsl:call-template name="displaySubHeading">
							<xsl:with-param name="id">head_pack_3a_<xsl:value-of select="$modeAdmin"/></xsl:with-param>
							<xsl:with-param name="secnr">3a</xsl:with-param>
						</xsl:call-template>
						<xsl:call-template name="displayElement">
							<xsl:with-param name="level">1</xsl:with-param>
							<xsl:with-param name="element">overdose_p</xsl:with-param>
						</xsl:call-template>
						<xsl:call-template name="displaySeparator"/>
					</xsl:if>
				</xsl:if>
				
				<xsl:if test="$section = '' or $section = 'head_pack_3' or $section = 'head_pack_3a_add'">
																																															<!-- SECTION 3 a add -->
					<xsl:variable name="nAdditional3a">
						<xsl:call-template name="countElementWithLocation">
							<xsl:with-param name="level">3</xsl:with-param>
							<xsl:with-param name="element">additional_section3_p</xsl:with-param>
							<xsl:with-param name="location">before-missed-info</xsl:with-param>
						</xsl:call-template>
					</xsl:variable>
					<xsl:if test="$nAdditional3a > 0">
						<xsl:call-template name="displayElementWithLocation">
							<xsl:with-param name="level">3</xsl:with-param>
							<xsl:with-param name="element">additional_section3_p</xsl:with-param>
							<xsl:with-param name="location">before-missed-info</xsl:with-param>
						</xsl:call-template>
						<xsl:call-template name="displaySeparator"/>
					</xsl:if>
				</xsl:if>
			
				<xsl:if test="$section = '' or $section = 'head_pack_3' or $section = 'head_pack_3b'">
																																															<!-- SECTION 3 b -->
					<xsl:variable name="nContent3b">
						<xsl:call-template name="countElement">
							<xsl:with-param name="level">2</xsl:with-param>
							<xsl:with-param name="element">missed_p</xsl:with-param>
						</xsl:call-template>
					</xsl:variable>
					<xsl:if test="$nContent3b > 0">
						<xsl:call-template name="displaySubHeading">
							<xsl:with-param name="id">head_pack_3b_<xsl:value-of select="$modeAdmin"/></xsl:with-param>
							<xsl:with-param name="secnr">3b</xsl:with-param>
						</xsl:call-template>
						<xsl:call-template name="displayElement">
							<xsl:with-param name="level">2</xsl:with-param>
							<xsl:with-param name="element">missed_p</xsl:with-param>
						</xsl:call-template>
						<xsl:call-template name="displaySeparator"/>
					</xsl:if>
				</xsl:if>
				
				<xsl:if test="$section = '' or $section = 'head_pack_3' or $section = 'head_pack_3b_add'">
																																															<!-- SECTION 3 b add -->
					<xsl:variable name="nAdditional3b">
						<xsl:call-template name="countElementWithLocation">
							<xsl:with-param name="level">3</xsl:with-param>
							<xsl:with-param name="element">additional_section3_p</xsl:with-param>
							<xsl:with-param name="location">before-withdrawal-info</xsl:with-param>
						</xsl:call-template>
					</xsl:variable>
					<xsl:if test="$nAdditional3b > 0">
						<xsl:call-template name="displayElementWithLocation">
							<xsl:with-param name="level">3</xsl:with-param>
							<xsl:with-param name="element">additional_section3_p</xsl:with-param>
							<xsl:with-param name="location">before-withdrawal-info</xsl:with-param>
						</xsl:call-template>
						<xsl:call-template name="displaySeparator"/>
					</xsl:if>
				</xsl:if>
				
				<xsl:if test="$section = '' or $section = 'head_pack_3' or $section = 'head_pack_3c'">
																																															<!-- SECTION 3 c -->
					<xsl:variable name="nContent3c">
						<xsl:call-template name="countElement">
							<xsl:with-param name="level">2</xsl:with-param>
							<xsl:with-param name="element">withdrawal_p</xsl:with-param>
						</xsl:call-template>
					</xsl:variable>
					<xsl:if test="$nContent3c > 0">
						<xsl:call-template name="displaySubHeading">
							<xsl:with-param name="id">head_pack_3c_<xsl:value-of select="$modeAdmin"/></xsl:with-param>
							<xsl:with-param name="secnr">3c</xsl:with-param>
						</xsl:call-template>
						<xsl:call-template name="displayElement">
							<xsl:with-param name="level">2</xsl:with-param>
							<xsl:with-param name="element">withdrawal_p</xsl:with-param>
						</xsl:call-template>
						<xsl:call-template name="displaySeparator"/>
					</xsl:if>
				</xsl:if>
				
				<xsl:if test="$section = '' or $section = 'head_pack_3' or $section = 'head_pack_3c_add'">
																																															<!-- SECTION 3 c add -->
					<xsl:variable name="nAdditional3c">
						<xsl:call-template name="countElementWithLocation">
							<xsl:with-param name="level">3</xsl:with-param>
							<xsl:with-param name="element">additional_section3_p</xsl:with-param>
							<xsl:with-param name="location">end</xsl:with-param>
						</xsl:call-template>
					</xsl:variable>
					<xsl:if test="$nAdditional3c > 0">
						<xsl:call-template name="displayElementWithLocation">
							<xsl:with-param name="level">3</xsl:with-param>
							<xsl:with-param name="element">additional_section3_p</xsl:with-param>
							<xsl:with-param name="location">end</xsl:with-param>
						</xsl:call-template>
						<xsl:call-template name="displaySeparator"/>
					</xsl:if>
				</xsl:if>
			</xsl:if>
				
			<xsl:call-template name="displaySeparator"/>
				
			<xsl:if test="$section = '' or $section = 'head_pack_4'">
																																																<!-- SECTION 4 -->
				<xsl:call-template name="displayHeading">
					<xsl:with-param name="id">head_pack_4</xsl:with-param>
					<xsl:with-param name="secnr">4</xsl:with-param>
				</xsl:call-template>
				
				<tr>
					<xsl:if test="$caller = 'pimrs'"><td><xsl:text> </xsl:text></td></xsl:if>
					<td>
						<xsl:call-template name="getCustomHeading">
							<xsl:with-param name="id">head_pack_4a</xsl:with-param>
						</xsl:call-template>
					</td>
				</tr>
				
				<xsl:call-template name="displayElement">
					<xsl:with-param name="level">2</xsl:with-param>
					<xsl:with-param name="element">undesirable_p</xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="displayText">
					<xsl:with-param name="id">head_pack_4b_<xsl:value-of select="/pim/documents/document[position() = $docpos]/@pl_sts_contact"/></xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="displaySeparator"/>
			</xsl:if>
			
			<xsl:call-template name="displaySeparator"/>
			
			<xsl:if test="$section = '' or $section = 'head_pack_5'">
																																																<!-- SECTION 5 -->
				<xsl:call-template name="displayHeading">
					<xsl:with-param name="id">head_pack_5</xsl:with-param>
					<xsl:with-param name="secnr">5</xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="displayText">
					<xsl:with-param name="id">head_pack_5a</xsl:with-param>
				</xsl:call-template>
				<tr>
					<xsl:if test="$caller = 'pimrs'">
						<td><xsl:text> </xsl:text></td>
					</xsl:if>
					<td width="100%">
						<xsl:variable name="ch5b">
							<xsl:call-template name="displayElement">
								<xsl:with-param name="level">1</xsl:with-param>
								<xsl:with-param name="element">head_pack_5b</xsl:with-param>
								<xsl:with-param name="mode">text</xsl:with-param>
							</xsl:call-template>
						</xsl:variable>
						<xsl:variable name="text5b">
							<xsl:call-template name="getHeadingText">
								<xsl:with-param name="id">head_pack_5b</xsl:with-param>
							</xsl:call-template>
						</xsl:variable>
						<xsl:variable name="heading5b">
							<xsl:choose>
								<xsl:when test="string-length($ch5b) > 0"><xsl:value-of select="$ch5b"/></xsl:when>
								<xsl:otherwise><xsl:value-of select="$text5b"/></xsl:otherwise>
							</xsl:choose>
						</xsl:variable>
						<xsl:variable name="productName">
							<xsl:call-template name="getProductName"/>
						</xsl:variable>
						<xsl:variable name="pack">
							<xsl:call-template name="displayElement">
								<xsl:with-param name="level">3</xsl:with-param>
								<xsl:with-param name="element">packaging_p</xsl:with-param>
								<xsl:with-param name="mode">text</xsl:with-param>
							</xsl:call-template>
						</xsl:variable>
						<font>
							<xsl:if test="string-length($ch5b) > 0">
								<xsl:attribute name="color">blue</xsl:attribute>
							</xsl:if>
							<xsl:call-template name="replace">
								<xsl:with-param name="text" select="$heading5b"/>
								<xsl:with-param name="pattern">$des_pack</xsl:with-param>
								<xsl:with-param name="value" select="$pack"/>
								<xsl:with-param name="pattern2">$des_product</xsl:with-param>
								<xsl:with-param name="value2" select="$productName"/>
							</xsl:call-template>
						</font>
					</td>
				</tr>
				<xsl:call-template name="displayElement">
					<xsl:with-param name="level">3</xsl:with-param>
					<xsl:with-param name="element">storage_shelf_p</xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="displayElement">
					<xsl:with-param name="level">3</xsl:with-param>
					<xsl:with-param name="element">storage_open_p</xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="displayElement">
					<xsl:with-param name="level">3</xsl:with-param>
					<xsl:with-param name="element">storage_reconstituted_p</xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="displayElement">
					<xsl:with-param name="level">3</xsl:with-param>
					<xsl:with-param name="element">life_open_p</xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="displayElement">
					<xsl:with-param name="level">3</xsl:with-param>
					<xsl:with-param name="element">life_reconstituted_p</xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="displayElement">
					<xsl:with-param name="level">1</xsl:with-param>
					<xsl:with-param name="element">visible_deterioration_p</xsl:with-param>
				</xsl:call-template>
				<xsl:variable name="pl_sts_5" select="/pim/documents/document[position() = $docpos]/@pl_sts_5"/>
				<xsl:if test="$pl_sts_5 = 'yes'">
					<xsl:call-template name="displayNode">
						<xsl:with-param name="id">head_pack_5c</xsl:with-param>
					</xsl:call-template>
				</xsl:if>
				<xsl:call-template name="displaySeparator"/>
			</xsl:if>
			
			<xsl:call-template name="displaySeparator"/>
			
			<xsl:if test="$section ='' or substring($section, 1, 11) = 'head_pack_6'">
				<xsl:if test="$section = '' or $section = 'head_pack_6'">
																																																<!-- SECTION 6 -->
					<xsl:call-template name="displayHeading">
						<xsl:with-param name="id">head_pack_6</xsl:with-param>
						<xsl:with-param name="secnr">6</xsl:with-param>
					</xsl:call-template>
				</xsl:if>
					
				<xsl:if test="$section = '' or $section = 'head_pack_6' or $section = 'head_pack_6a'">
																																															<!-- SECTION 6 a -->
					<xsl:call-template name="displaySubHeading">
						<xsl:with-param name="id">head_pack_6a</xsl:with-param>
						<xsl:with-param name="secnr">6a</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="displayElement">
						<xsl:with-param name="level">2</xsl:with-param>
						<xsl:with-param name="element">composition_p</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="displayElement">
						<xsl:with-param name="level">2</xsl:with-param>
						<xsl:with-param name="element">excipient_all_p</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="displaySeparator"/>
				</xsl:if>
				
				<xsl:if test="$section = '' or $section = 'head_pack_6' or $section = 'head_pack_6b'">
																																															<!-- SECTION 6 b -->
					<xsl:call-template name="displaySubHeading">
						<xsl:with-param name="id">head_pack_6b</xsl:with-param>
						<xsl:with-param name="secnr">6b</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="displayElement">
						<xsl:with-param name="level">3</xsl:with-param>
						<xsl:with-param name="element">presentation_appearance_p</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="displaySeparator"/>
				</xsl:if>
				
				<xsl:variable name="holder">
					<xsl:call-template name="displayElement">
						<xsl:with-param name="level">0</xsl:with-param>
						<xsl:with-param name="element">holder_p</xsl:with-param>
					</xsl:call-template>
				</xsl:variable>
				<xsl:variable name="manufacturer">
					<xsl:call-template name="displayElement">
						<xsl:with-param name="level">2</xsl:with-param>
						<xsl:with-param name="element">manufacturer</xsl:with-param>
					</xsl:call-template>
				</xsl:variable>
				
				<xsl:if test="$holder = $manufacturer">
					<xsl:if test="$section = '' or $section = 'head_pack_6' or $section = 'head_pack_6c'">
																																															<!-- SECTION 6 c -->
						<xsl:call-template name="displaySubHeading">
							<xsl:with-param name="id">head_pack_6c</xsl:with-param>
							<xsl:with-param name="secnr">6c</xsl:with-param>
						</xsl:call-template>
						<xsl:call-template name="displayElement">
							<xsl:with-param name="level">0</xsl:with-param>
							<xsl:with-param name="element">holder_p</xsl:with-param>
						</xsl:call-template>
						<xsl:call-template name="displaySeparator"/>
					</xsl:if>
				</xsl:if>
				<xsl:if test="$holder != $manufacturer">
					<xsl:if test="$section = '' or $section = 'head_pack_6' or $section = 'head_pack_6d'">
																																															<!-- SECTION 6 d -->
						<xsl:call-template name="displaySubHeading">
							<xsl:with-param name="id">head_pack_6d</xsl:with-param>
							<xsl:with-param name="secnr">6d</xsl:with-param>
						</xsl:call-template>
						<xsl:call-template name="displayElement">
							<xsl:with-param name="level">0</xsl:with-param>
							<xsl:with-param name="element">holder_p</xsl:with-param>
						</xsl:call-template>
						<xsl:call-template name="displaySeparator"/>
					</xsl:if>
					<xsl:if test="string-length($manufacturer) > 0">
						<xsl:if test="$section = '' or $section = 'head_pack_6' or $section = 'head_pack_6e'">
																																																<!-- SECTION 6 e -->
							<xsl:call-template name="displaySubHeading">
								<xsl:with-param name="id">head_pack_6e</xsl:with-param>
								<xsl:with-param name="secnr">6e</xsl:with-param>
							</xsl:call-template>
							<xsl:call-template name="displayElement">
								<xsl:with-param name="level">2</xsl:with-param>
								<xsl:with-param name="element">manufacturer</xsl:with-param>
							</xsl:call-template>
							<xsl:call-template name="displaySeparator"/>
						</xsl:if>
					</xsl:if>
				</xsl:if>
				<xsl:if test="$section = '' or $section = 'head_pack_6' or $section = 'head_pack_6f'">
																																															<!-- SECTION 6 f -->
					<xsl:call-template name="displayText">
						<xsl:with-param name="id">head_pack_6f</xsl:with-param>
						<xsl:with-param name="secnr">6f</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="displayElement">
						<xsl:with-param name="level">0</xsl:with-param>
						<xsl:with-param name="element">representative</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="displaySeparator"/>
				</xsl:if>
				<xsl:if test="$section = '' or $section = 'head_pack_6' or $section = 'head_pack_6g'">
																																															<!-- SECTION 6 g -->
					<tr>
						<xsl:if test="$caller = 'pimrs'">
							<td><xsl:text> </xsl:text></td>
						</xsl:if>
						<td width="100%">
							<h2>
								<xsl:call-template name="getHeadingText">
									<xsl:with-param name="id">head_pack_6g_date</xsl:with-param>
								</xsl:call-template>
								<xsl:call-template name="displayElement">
									<xsl:with-param name="level">2</xsl:with-param>
									<xsl:with-param name="element">revision_p</xsl:with-param>
									<xsl:with-param name="mode">text</xsl:with-param>
								</xsl:call-template>
							</h2>
						</td>
					</tr>
					<xsl:call-template name="displaySeparator"/>
					<xsl:call-template name="approvalMode"/>
					<xsl:call-template name="displaySeparator"/>
					<xsl:variable name="pl_sts_end" select="/pim/documents/document[position() = $docpos]/@pl_sts_end"/>
					<xsl:variable name="orphan" select="/pim/level_product/@orphan"/>
					<xsl:if test="$pl_sts_end = 'yes' and $orphan = 'yes'">
						<xsl:call-template name="displayNode">
							<xsl:with-param name="id">head_pack_6h_orphan</xsl:with-param>
						</xsl:call-template>
						<xsl:call-template name="displaySeparator"/>
					</xsl:if>
					<xsl:if test="$pl_sts_end = 'yes' and $orphan = 'no'">
						<xsl:call-template name="displayNode">
							<xsl:with-param name="id">head_pack_6h</xsl:with-param>
						</xsl:call-template>
						<xsl:call-template name="displaySeparator"/>
					</xsl:if>
				</xsl:if>
			</xsl:if>
			
			<xsl:if test="$section = '' or $section = 'head_pack_7'">
																																																<!-- SECTION 7 -->
				<xsl:variable name="healthcare_information">
					<xsl:call-template name="displayElement">
						<xsl:with-param name="level">3</xsl:with-param>
						<xsl:with-param name="element">healthcare_information_p</xsl:with-param>
					</xsl:call-template>
				</xsl:variable>
				<xsl:if test="string-length($healthcare_information) > 0">
					<tr>
						<xsl:if test="$caller = 'pimrs'">
							<td><xsl:text> </xsl:text></td>
						</xsl:if>
						<td width="100%">
							<hr/>
						</td>
					</tr>
					<xsl:call-template name="displaySeparator"/>
					<xsl:call-template name="displayText">
						<xsl:with-param name="id">head_pack_7</xsl:with-param>
						<xsl:with-param name="secnr">7</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="displayElement">
						<xsl:with-param name="level">3</xsl:with-param>
						<xsl:with-param name="element">healthcare_information_p</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="displaySeparator"/>
				</xsl:if>
				<xsl:variable name="other_information">
					<xsl:call-template name="displayElement">
						<xsl:with-param name="level">3</xsl:with-param>
						<xsl:with-param name="element">other_information_p</xsl:with-param>
					</xsl:call-template>
				</xsl:variable>
				<xsl:if test="string-length($other_information) > 0">
					<xsl:call-template name="displayPageBreak"/>
					<xsl:call-template name="displayElement">
						<xsl:with-param name="level">3</xsl:with-param>
						<xsl:with-param name="element">other_information_p</xsl:with-param>
					</xsl:call-template>
				</xsl:if>
			</xsl:if>
		</table>
		<br/><br/>
		<xsl:if test="$section = '' and $caller = ''">
			<font size="-5">Leaflet style sheet version <xsl:value-of select="$xsl-ver"/></font>
		</xsl:if>
	</body>
</html>
</xsl:template>

<!-- Special case of Top: name of the medicinal product -->
<xsl:template name="nameMedicinalProduct">
	<xsl:variable name="nQualBeforeInv">
		<xsl:call-template name="countDifferentElement">
			<xsl:with-param name="level">3</xsl:with-param>
			<xsl:with-param name="element">qual_before_inv</xsl:with-param>
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="nQualAfterInv">
		<xsl:call-template name="countDifferentElement">
			<xsl:with-param name="level">3</xsl:with-param>
			<xsl:with-param name="element">qual_after_inv</xsl:with-param>
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="nStrength">
		<xsl:call-template name="countElement">
			<xsl:with-param name="level">2</xsl:with-param>
			<xsl:with-param name="element">strength</xsl:with-param>
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="nQualStrength">
		<xsl:call-template name="countDifferentElement">
			<xsl:with-param name="level">3</xsl:with-param>
			<xsl:with-param name="element">qual_strength</xsl:with-param>
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="nQualForm">
		<xsl:call-template name="countDifferentElement">
			<xsl:with-param name="level">3</xsl:with-param>
			<xsl:with-param name="element">qual_form_p</xsl:with-param>
		</xsl:call-template>
	</xsl:variable>
	
	<xsl:choose>
		<xsl:when test="contains($nQualBeforeInv, 'N') or contains($nQualAfterInv, 'N') or contains($nQualStrength, 'N') or contains($nQualForm, 'N')">
			<xsl:choose>
				<xsl:when test="$nStrength > 1">
					<xsl:for-each select="/pim/documents/document[position() = $docpos]/pi-level">
						<xsl:variable name="level_id" select="@ref-id"/>
						<xsl:for-each select="key('level_id', $level_id)//strength">
							<xsl:variable name="str-pos" select="position()"/>
							<xsl:for-each select="../level_presentation">
								<tr>
									<xsl:if test="$caller = 'pimrs'">
										<td><xsl:text> </xsl:text></td>
									</xsl:if>
									<td width="100%" class="pl-title">
										<xsl:for-each select="qual_before_inv/pi-group/pi-leaf">
											<xsl:call-template name="displayTemplateText">
												<xsl:with-param name="id" select="@ref-id"/>
											</xsl:call-template>
										</xsl:for-each>
										<xsl:for-each select="../../../invented_name/pi-group/pi-leaf">
											<xsl:call-template name="displayTemplateText">
												<xsl:with-param name="id" select="@ref-id"/>
											</xsl:call-template>
										</xsl:for-each>
										<xsl:for-each select="qual_after_inv/pi-group/pi-leaf">
											<xsl:call-template name="displayTemplateText">
												<xsl:with-param name="id" select="@ref-id"/>
											</xsl:call-template>
										</xsl:for-each>
										<xsl:for-each select="../strength[$str-pos]/pi-group/pi-leaf">
											<xsl:call-template name="displayTemplateText">
												<xsl:with-param name="id" select="@ref-id"/>
											</xsl:call-template>
										</xsl:for-each>
										<xsl:for-each select="qual_strength/pi-group/pi-leaf">
											<xsl:call-template name="displayTemplateText">
												<xsl:with-param name="id" select="@ref-id"/>
											</xsl:call-template>
										</xsl:for-each>
										<xsl:for-each select="../../form_inline_p/pi-group/pi-leaf">
											<xsl:call-template name="displayTemplateText">
												<xsl:with-param name="id" select="@ref-id"/>
											</xsl:call-template>
										</xsl:for-each>
										<xsl:for-each select="qual_form_p/pi-group/pi-leaf">
											<xsl:call-template name="displayTemplateText">
												<xsl:with-param name="id" select="@ref-id"/>
											</xsl:call-template>
										</xsl:for-each>
									</td>
								</tr>
							</xsl:for-each>
						</xsl:for-each>
					</xsl:for-each>
				</xsl:when>
				<xsl:otherwise>
					<xsl:for-each select="/pim/documents/document[position() = $docpos]/pi-level">
						<xsl:variable name="level_id" select="@ref-id"/>
						<xsl:for-each select="key('level_id', $level_id)//level_presentation">
							<tr>
								<xsl:if test="$caller = 'pimrs'">
									<td><xsl:text> </xsl:text></td>
								</xsl:if>
								<td width="100%" class="pl-title">
									<xsl:for-each select="qual_before_inv/pi-group/pi-leaf">
										<xsl:call-template name="displayTemplateText">
											<xsl:with-param name="id" select="@ref-id"/>
										</xsl:call-template>
									</xsl:for-each>
									<xsl:call-template name="displayElement">
										<xsl:with-param name="level">0</xsl:with-param>
										<xsl:with-param name="element">invented_name</xsl:with-param>
										<xsl:with-param name="mode">text</xsl:with-param>
									</xsl:call-template>
									<xsl:for-each select="qual_after_inv/pi-group/pi-leaf">
										<xsl:call-template name="displayTemplateText">
											<xsl:with-param name="id" select="@ref-id"/>
										</xsl:call-template>
									</xsl:for-each>
									<xsl:call-template name="displayElement">
										<xsl:with-param name="level">2</xsl:with-param>
										<xsl:with-param name="element">strength</xsl:with-param>
										<xsl:with-param name="mode">text</xsl:with-param>
									</xsl:call-template>
									<xsl:for-each select="qual_strength/pi-group/pi-leaf">
										<xsl:call-template name="displayTemplateText">
											<xsl:with-param name="id" select="@ref-id"/>
										</xsl:call-template>
									</xsl:for-each>
									<xsl:call-template name="displayElement">
										<xsl:with-param name="level">1</xsl:with-param>
										<xsl:with-param name="element">form_inline_p</xsl:with-param>
										<xsl:with-param name="mode">text</xsl:with-param>
									</xsl:call-template>
									<xsl:for-each select="qual_form_p/pi-group/pi-leaf">
										<xsl:call-template name="displayTemplateText">
											<xsl:with-param name="id" select="@ref-id"/>
										</xsl:call-template>
									</xsl:for-each>
								</td>
							</tr>
						</xsl:for-each>
					</xsl:for-each>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:when>
		<xsl:otherwise>
			<xsl:choose>
				<xsl:when test="$nStrength > 1">
					<xsl:for-each select="/pim/documents/document[position() = $docpos]/pi-level">
						<xsl:variable name="level_id" select="@ref-id"/>
						<xsl:for-each select="key('level_id', $level_id)//strength">
							<tr>
								<xsl:if test="$caller = 'pimrs'">
									<td><xsl:text> </xsl:text></td>
								</xsl:if>
								<td width="100%" class="pl-title">
									<xsl:call-template name="displayElement">
										<xsl:with-param name="level">3</xsl:with-param>
										<xsl:with-param name="element">qual_before_inv</xsl:with-param>
										<xsl:with-param name="mode">text</xsl:with-param>
									</xsl:call-template>
									<xsl:call-template name="displayElement">
										<xsl:with-param name="level">0</xsl:with-param>
										<xsl:with-param name="element">invented_name</xsl:with-param>
										<xsl:with-param name="mode">text</xsl:with-param>
									</xsl:call-template>
									<xsl:call-template name="displayElement">
										<xsl:with-param name="level">3</xsl:with-param>
										<xsl:with-param name="element">qual_after_inv</xsl:with-param>
										<xsl:with-param name="mode">text</xsl:with-param>
									</xsl:call-template>
									<xsl:for-each select="pi-group/pi-leaf">
										<xsl:call-template name="displayTemplateText">
											<xsl:with-param name="id" select="@ref-id"/>
										</xsl:call-template>
									</xsl:for-each>
									<xsl:call-template name="displayElement">
										<xsl:with-param name="level">3</xsl:with-param>
										<xsl:with-param name="element">qual_strength</xsl:with-param>
										<xsl:with-param name="mode">text</xsl:with-param>
									</xsl:call-template>
									<xsl:call-template name="displayElement">
										<xsl:with-param name="level">1</xsl:with-param>
										<xsl:with-param name="element">form_inline_p</xsl:with-param>
										<xsl:with-param name="mode">text</xsl:with-param>
									</xsl:call-template>
									<xsl:call-template name="displayElement">
										<xsl:with-param name="level">3</xsl:with-param>
										<xsl:with-param name="element">qual_form_p</xsl:with-param>
										<xsl:with-param name="mode">text</xsl:with-param>
									</xsl:call-template>
								</td>
							</tr>
						</xsl:for-each>
					</xsl:for-each>
				</xsl:when>
				<xsl:otherwise>
					<tr>
						<xsl:if test="$caller = 'pimrs'">
							<td><xsl:text> </xsl:text></td>
						</xsl:if>
						<td width="100%" class="pl-title">
							<xsl:call-template name="displayElement">
								<xsl:with-param name="level">3</xsl:with-param>
								<xsl:with-param name="element">qual_before_inv</xsl:with-param>
								<xsl:with-param name="mode">text</xsl:with-param>
							</xsl:call-template>
							<xsl:call-template name="displayElement">
								<xsl:with-param name="level">0</xsl:with-param>
								<xsl:with-param name="element">invented_name</xsl:with-param>
								<xsl:with-param name="mode">text</xsl:with-param>
							</xsl:call-template>
							<xsl:call-template name="displayElement">
								<xsl:with-param name="level">3</xsl:with-param>
								<xsl:with-param name="element">qual_after_inv</xsl:with-param>
								<xsl:with-param name="mode">text</xsl:with-param>
							</xsl:call-template>
							<xsl:call-template name="displayElement">
								<xsl:with-param name="level">2</xsl:with-param>
								<xsl:with-param name="element">strength</xsl:with-param>
								<xsl:with-param name="mode">text</xsl:with-param>
							</xsl:call-template>
							<xsl:call-template name="displayElement">
								<xsl:with-param name="level">3</xsl:with-param>
								<xsl:with-param name="element">qual_strength</xsl:with-param>
								<xsl:with-param name="mode">text</xsl:with-param>
							</xsl:call-template>
							<xsl:call-template name="displayElement">
								<xsl:with-param name="level">1</xsl:with-param>
								<xsl:with-param name="element">form_inline_p</xsl:with-param>
								<xsl:with-param name="mode">text</xsl:with-param>
							</xsl:call-template>
							<xsl:call-template name="displayElement">
								<xsl:with-param name="level">3</xsl:with-param>
								<xsl:with-param name="element">qual_form_p</xsl:with-param>
								<xsl:with-param name="mode">text</xsl:with-param>
							</xsl:call-template>
						</td>
					</tr>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- Special case of Top: common name and substance -->
<xsl:template name="commonNameSubstance">
	<xsl:variable name="commonName">
		<xsl:call-template name="displayElement">
			<xsl:with-param name="level">0</xsl:with-param>
			<xsl:with-param name="element">common_name_p</xsl:with-param>
			<xsl:with-param name="mode">list</xsl:with-param>
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="substance">
		<xsl:call-template name="displayElement">
			<xsl:with-param name="level">0</xsl:with-param>
			<xsl:with-param name="element">substance</xsl:with-param>
			<xsl:with-param name="mode">list</xsl:with-param>
		</xsl:call-template>
	</xsl:variable>
	
	<xsl:choose>
		<xsl:when test="$commonName = $substance">
			<xsl:call-template name="displayElement">
				<xsl:with-param name="level">0</xsl:with-param>
				<xsl:with-param name="element">substance</xsl:with-param>
				<xsl:with-param name="align">center</xsl:with-param>
			</xsl:call-template>
		</xsl:when>
		<xsl:otherwise>
			<xsl:call-template name="displayElement">
				<xsl:with-param name="level">0</xsl:with-param>
				<xsl:with-param name="element">common_name_p</xsl:with-param>
				<xsl:with-param name="align">center</xsl:with-param>
			</xsl:call-template>
			<xsl:call-template name="displayElement">
				<xsl:with-param name="level">0</xsl:with-param>
				<xsl:with-param name="element">substance</xsl:with-param>
				<xsl:with-param name="align">center</xsl:with-param>
			</xsl:call-template>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- Special case of Top: OTC or POM box -->
<xsl:template name="boxOtcPom">
	<xsl:variable name="level_id" select="/pim/documents/document[position() = $docpos]/pi-level[1]/@ref-id"/>
	<xsl:variable name="case" select="key('level_id', $level_id)//legal_status_o/@case"/>
	<xsl:variable name="mode_admin" select="key('level_id', $level_id)//level_outer[1]/../../../mode_administration/@verb"/>
	<xsl:variable name="contact" select="/pim/documents/document[position() = $docpos]/@pl_sts_contact"/>
	<xsl:variable name="otc" select="/pim/documents/document[position() = $docpos]/@pl_sts_otc"/>
	
	<xsl:variable name="resolutionPeriod">
		<xsl:call-template name="displayElement">
			<xsl:with-param name="level">2</xsl:with-param>
			<xsl:with-param name="element">resolution_period_p</xsl:with-param>
			<xsl:with-param name="mode">list</xsl:with-param>
		</xsl:call-template>
	</xsl:variable>
	
	<xsl:variable name="ch-pom">
		<xsl:call-template name="displayElement">
			<xsl:with-param name="level">1</xsl:with-param>
			<xsl:with-param name="element">pom_box_title</xsl:with-param>
			<xsl:with-param name="mode">text</xsl:with-param>
		</xsl:call-template>
	</xsl:variable>
	
	<xsl:variable name="ch-otc">
		<xsl:call-template name="displayElement">
			<xsl:with-param name="level">1</xsl:with-param>
			<xsl:with-param name="element">otc_box_1</xsl:with-param>
			<xsl:with-param name="mode">text</xsl:with-param>
		</xsl:call-template>
	</xsl:variable>
	
	<tr>
		<xsl:if test="$caller = 'pimrs'">
			<td><xsl:text> </xsl:text></td>
		</xsl:if>
		<td width="100%">
			<xsl:choose>
				<xsl:when test="$case = 'without-prescription'">
					<h2>
						<xsl:call-template name="getHeadingText">
							<xsl:with-param name="id">otc_box_title_<xsl:value-of select="$mode_admin"/>_<xsl:value-of select="$otc"/></xsl:with-param>
						</xsl:call-template>
					</h2>
					<xsl:call-template name="getCustomHeading">
						<xsl:with-param name="id">otc_box_1_<xsl:value-of select="$mode_admin"/>_<xsl:value-of select="$contact"/></xsl:with-param>
					</xsl:call-template>
					<table width="100%" cellpadding="0" cellspacing="0" style="color:black">
						<tr>
							<td width="20px" valign="top" style="padding-right: 15px">-</td>
							<td>
								<xsl:call-template name="getHeadingText">
									<xsl:with-param name="id">otc_box_2</xsl:with-param>
								</xsl:call-template>
							</td>
						</tr>
						<tr>
							<td width="20px" valign="top" style="padding-right: 15px">-</td>
							<td>
								<xsl:call-template name="getHeadingText">
									<xsl:with-param name="id">otc_box_3</xsl:with-param>
								</xsl:call-template>
							</td>
						</tr>
						<tr>
							<td width="20px" valign="top" style="padding-right: 15px">-</td>
							<td>
								<xsl:choose>
									<xsl:when test="$resolutionPeriod = ''">
										<xsl:call-template name="getHeadingText">
											<xsl:with-param name="id">otc_box_4_short</xsl:with-param>
										</xsl:call-template>
									</xsl:when>
									<xsl:otherwise>
										<xsl:call-template name="getHeadingText">
											<xsl:with-param name="id">otc_box_4_days</xsl:with-param>
											<xsl:with-param name="pattern">$des_resolution_days</xsl:with-param>
											<xsl:with-param name="level">2</xsl:with-param>
											<xsl:with-param name="element">resolution_period_p</xsl:with-param>
										</xsl:call-template>
									</xsl:otherwise>
								</xsl:choose>
							</td>
						</tr>
						<tr>
							<td width="20px" valign="top" style="padding-right: 15px">-</td>
							<td>
								<xsl:call-template name="getHeadingText">
									<xsl:with-param name="id">otc_box_5_<xsl:value-of select="$contact"/></xsl:with-param>
								</xsl:call-template>
							</td>
						</tr>
					</table>
				</xsl:when>
				<xsl:otherwise>
					<h2>
						<xsl:call-template name="getCustomHeading">
							<xsl:with-param name="id">pom_box_title_<xsl:value-of select="$mode_admin"/></xsl:with-param>
						</xsl:call-template>
					</h2>
					<table width="100%" cellpadding="0" cellspacing="0" style="color:black">
						<tr>
							<td width="20px" valign="top" style="padding-right: 15px">-</td>
							<td>
								<xsl:call-template name="getHeadingText">
									<xsl:with-param name="id">pom_box_1</xsl:with-param>
								</xsl:call-template>
							</td>
						</tr>
						<tr>
							<td width="20px" valign="top" style="padding-right: 15px">-</td>
							<td>
								<xsl:call-template name="getHeadingText">
									<xsl:with-param name="id">pom_box_2_<xsl:value-of select="$contact"/></xsl:with-param>
								</xsl:call-template>
							</td>
						</tr>
						<xsl:if test="/pim/documents/document[position() = $docpos]/@pl_sts_pom != '3points'">
							<tr>
								<td width="20px" valign="top" style="padding-right: 15px">-</td>
								<td>
									<xsl:call-template name="getHeadingText">
										<xsl:with-param name="id">pom_box_3</xsl:with-param>
									</xsl:call-template>
								</td>
							</tr>
						</xsl:if>
						<tr>
							<td width="20px" valign="top" style="padding-right: 15px">-</td>
							<td>
								<xsl:call-template name="getHeadingText">
									<xsl:with-param name="id">pom_box_4_<xsl:value-of select="$contact"/></xsl:with-param>
								</xsl:call-template>
							</td>
						</tr>
					</table>	
				</xsl:otherwise>
			</xsl:choose>
		</td>
	</tr>
</xsl:template>

<!-- Special case of Section 6: approval mode -->
<xsl:template name="approvalMode">
	<tr>
		<xsl:if test="$caller = 'pimrs'">
			<td><xsl:text> </xsl:text></td>
		</xsl:if>
		<td width="100%">
			<xsl:variable name="mode"><xsl:value-of select="/pim/level_product/approval/@mode"/></xsl:variable>
			<xsl:if test="$mode != 'complete'">
				<xsl:call-template name="displayText">
					<xsl:with-param name="id">head_pack_6g_<xsl:value-of select="$mode"/>_a</xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="displayText">
					<xsl:with-param name="id">head_pack_6g_<xsl:value-of select="$mode"/>_b</xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="displayText">
					<xsl:with-param name="id">head_pack_6g_<xsl:value-of select="$mode"/>_c</xsl:with-param>
				</xsl:call-template>
			</xsl:if>
		</td>
	</tr>
</xsl:template>

</xsl:stylesheet>