<?xml version="1.0" encoding="utf-8"?>

<!-- 
	Version 2.6
	27 March 2006

	Author:
		Laurent Desqueper
-->

<xsl:stylesheet version="1.0"
	xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
	xmlns:ectd="http://www.ich.org/ectd" 
	xmlns:xlink="http://www.w3c.org/1999/xlink">

<!-- include combination and layout style sheets -->
<xsl:include href="common.xsl"/>
<xsl:include href="combined.xsl"/>
<xsl:include href="layout.xsl"/>

<!-- style sheet parameters -->
<xsl:param name="docpos"/>			<!-- The position of the PI to generate in the document zone -->
<xsl:param name="depth"/>			<!-- The level where the generate the PI as Integer: prd(0), frm(1), str(2), prs(3) -->
<xsl:param name="lang"/>				<!-- The language of the PI document to generate -->
<xsl:param name="caller"/>			<!-- The caller of the stylesheet : if empty, caller is the PIM Viewer -->
<xsl:param name="section"/>			<!-- The section to display : if empty, all document displays -->

<!-- style sheet version number -->
<xsl:param name="xsl-ver">2.6</xsl:param>

<!-- set output type to XHTML -->
<xsl:output indent="yes" method="xml"/>

<!-- structure of the document -->
<xsl:template match="/">
<html>
	<head>
		<title>
			<xsl:call-template name="getHeadingText"><xsl:with-param name="id">anx1_title</xsl:with-param></xsl:call-template>
			-
			<xsl:call-template name="getHeadingText"><xsl:with-param name="id">spc_title</xsl:with-param></xsl:call-template>
		</title>
		<link href="util/style/doc.css" rel="stylesheet"/>
	</head>
	<body background="util/style/watermark.gif">
		<xsl:if test="$section =''">
																																																	<!-- COMMENTS -->
			<xsl:if test="count(/pim/documents/document[position() = $docpos]/comment[string-length(@section) = 0 and @lang=$lang]) > 0">
				<b><u>Comment on <xsl:call-template name="getDocumentType"/>:</u></b>
				<ul>
					<xsl:apply-templates select="/pim/documents/document[position() = $docpos]/comment[string-length(@section) = 0 and @lang=$lang]" mode="doc"/>
				</ul>
			</xsl:if>
																																																	<!-- TITLE -->
			<center class="page-break">			
				<h1>
					<br style="line-height: 98mm"/>
					<xsl:call-template name="getHeadingText"><xsl:with-param name="id">anx1_title</xsl:with-param></xsl:call-template>
					<br/><br/>
					<xsl:call-template name="getHeadingText"><xsl:with-param name="id">spc_title</xsl:with-param></xsl:call-template>
				</h1>
				<br style="line-height: 30mm"/>
			</center>
		</xsl:if>
		<table cellpadding="1" cellspacing="0" width="100%" style="color:black">
			<xsl:if test="$section = '' or $section = 'spc_1'">
																																																	<!-- SECTION 1 -->
				<xsl:call-template name="displayHeading">
					<xsl:with-param name="id">spc_1</xsl:with-param>
					<xsl:with-param name="secnr">1</xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="nameMedicinalProduct"/>
				<xsl:call-template name="displayElement">
					<xsl:with-param name="level">0</xsl:with-param>
					<xsl:with-param name="element">common_name_s</xsl:with-param>
				</xsl:call-template>
			</xsl:if>

			<xsl:call-template name="displaySeparator"/>
			<xsl:call-template name="displaySeparator"/>

			<xsl:if test="$section = '' or $section = 'spc_2'">
																																																	<!-- SECTION 2 -->
				<xsl:call-template name="displayHeading">
					<xsl:with-param name="id">spc_2</xsl:with-param>
					<xsl:with-param name="secnr">2</xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="displayElement">
					<xsl:with-param name="level">2</xsl:with-param>
					<xsl:with-param name="element">composition_active_s</xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="displayElement">
					<xsl:with-param name="level">2</xsl:with-param>
					<xsl:with-param name="element">composition_excipient_s</xsl:with-param>
				</xsl:call-template>
	
				<xsl:call-template name="displayText">
					<xsl:with-param name="id">spc_2a</xsl:with-param>
				</xsl:call-template>
			</xsl:if>
			
			<xsl:call-template name="displaySeparator"/>
			<xsl:call-template name="displaySeparator"/>

			<xsl:if test="$section = '' or $section = 'spc_3'">
																																																	<!-- SECTION 3 -->
				<xsl:call-template name="displayHeading">
					<xsl:with-param name="id">spc_3</xsl:with-param>
					<xsl:with-param name="secnr">3</xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="pharmaceuticalForm"/>
				<xsl:call-template name="displayElement">
					<xsl:with-param name="level">2</xsl:with-param>
					<xsl:with-param name="element">appearance_s</xsl:with-param>
				</xsl:call-template>
			</xsl:if>

			<xsl:call-template name="displaySeparator"/>
			<xsl:call-template name="displaySeparator"/>

			<xsl:if test="$section = '' or substring($section, 1, 5) = 'spc_4'">
																																																	<!-- SECTION 4 -->
				<xsl:if test="$section = '' or $section = 'spc_4'">
					<xsl:call-template name="displayHeading">
						<xsl:with-param name="id">spc_4</xsl:with-param>
						<xsl:with-param name="secnr">4</xsl:with-param>
					</xsl:call-template>
				</xsl:if>

				<xsl:if test="$section = '' or $section = 'spc_4' or $section = 'spc_41'">
																																																		<!-- SECTION 4.1 -->
					<xsl:call-template name="displaySubHeading">
						<xsl:with-param name="id">spc_41</xsl:with-param>
						<xsl:with-param name="secnr">4.1</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="displayElement">
						<xsl:with-param name="level">2</xsl:with-param>
						<xsl:with-param name="element">indication_s</xsl:with-param>
					</xsl:call-template>
				</xsl:if>

				<xsl:call-template name="displaySeparator"/>
	
				<xsl:if test="$section = '' or $section = 'spc_4'  or $section = 'spc_42'">
																																																		<!-- SECTION 4.2 -->
					<xsl:call-template name="displaySubHeading">
						<xsl:with-param name="id">spc_42</xsl:with-param>
						<xsl:with-param name="secnr">4.2</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="displayElement">
						<xsl:with-param name="level">3</xsl:with-param>
						<xsl:with-param name="element">administration_s</xsl:with-param>
					</xsl:call-template>
				</xsl:if>
	
				<xsl:call-template name="displaySeparator"/>
	
				<xsl:if test="$section = '' or $section = 'spc_4'  or $section = 'spc_43'">
																																																		<!-- SECTION 4.3 -->
					<xsl:call-template name="displaySubHeading">
						<xsl:with-param name="id">spc_43</xsl:with-param>
						<xsl:with-param name="secnr">4.3</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="displayElement">
						<xsl:with-param name="level">2</xsl:with-param>
						<xsl:with-param name="element">contraindication_s</xsl:with-param>
					</xsl:call-template>
				</xsl:if>
				
				<xsl:call-template name="displaySeparator"/>
				
				<xsl:if test="$section = '' or $section = 'spc_4'  or $section = 'spc_44'">
																																																		<!-- SECTION 4.4 -->
					<xsl:call-template name="displaySubHeading">
						<xsl:with-param name="id">spc_44</xsl:with-param>
						<xsl:with-param name="secnr">4.4</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="displayElement">
						<xsl:with-param name="level">3</xsl:with-param>
						<xsl:with-param name="element">warning_s</xsl:with-param>
					</xsl:call-template>
				</xsl:if>
				
				<xsl:call-template name="displaySeparator"/>
				
				<xsl:if test="$section = '' or $section = 'spc_4'  or $section = 'spc_45'">
																																																		<!-- SECTION 4.5 -->
					<xsl:call-template name="displaySubHeading">
						<xsl:with-param name="id">spc_45</xsl:with-param>
						<xsl:with-param name="secnr">4.5</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="displayElement">
						<xsl:with-param name="level">1</xsl:with-param>
						<xsl:with-param name="element">interaction_medical_s</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="displayElement">
						<xsl:with-param name="level">1</xsl:with-param>
						<xsl:with-param name="element">interaction_food_s</xsl:with-param>
					</xsl:call-template>
				</xsl:if>
				
				<xsl:call-template name="displaySeparator"/>
				
				<xsl:if test="$section = '' or $section = 'spc_4'  or $section = 'spc_46'">
																																																		<!-- SECTION 4.6 -->
					<xsl:call-template name="displaySubHeading">
						<xsl:with-param name="id">spc_46</xsl:with-param>
						<xsl:with-param name="secnr">4.6</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="displayElement">
						<xsl:with-param name="level">1</xsl:with-param>
						<xsl:with-param name="element">pregnancy_lactation_s</xsl:with-param>
					</xsl:call-template>
				</xsl:if>
				
				<xsl:call-template name="displaySeparator"/>
				
				<xsl:if test="$section = '' or $section = 'spc_4'  or $section = 'spc_47'">
																																																		<!-- SECTION 4.7 -->
					<xsl:call-template name="displaySubHeading">
						<xsl:with-param name="id">spc_47</xsl:with-param>
						<xsl:with-param name="secnr">4.7</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="displayElement">
						<xsl:with-param name="level">1</xsl:with-param>
						<xsl:with-param name="element">driving_s</xsl:with-param>
					</xsl:call-template>
				</xsl:if>
				
				<xsl:call-template name="displaySeparator"/>
				
				<xsl:if test="$section = '' or $section = 'spc_4'  or $section = 'spc_48'">
																																																		<!-- SECTION 4.8 -->
					<xsl:call-template name="displaySubHeading">
						<xsl:with-param name="id">spc_48</xsl:with-param>
						<xsl:with-param name="secnr">4.8</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="displayElement">
						<xsl:with-param name="level">2</xsl:with-param>
						<xsl:with-param name="element">undesirable_s</xsl:with-param>
					</xsl:call-template>
				</xsl:if>
				
				<xsl:call-template name="displaySeparator"/>
				
				<xsl:if test="$section = '' or $section = 'spc_4'  or $section = 'spc_49'">
																																																		<!-- SECTION 4.9 -->
					<xsl:call-template name="displaySubHeading">
						<xsl:with-param name="id">spc_49</xsl:with-param>
						<xsl:with-param name="secnr">4.9</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="displayElement">
						<xsl:with-param name="level">1</xsl:with-param>
						<xsl:with-param name="element">overdose_s</xsl:with-param>
					</xsl:call-template>
				</xsl:if>
			</xsl:if>

			<xsl:call-template name="displaySeparator"/>
			<xsl:call-template name="displaySeparator"/>
	
			<xsl:if test="$section = '' or substring($section, 1, 5) = 'spc_5'">
																																																		<!-- SECTION 5 -->
				<xsl:if test="$section = '' or $section = 'spc_5'">
					<xsl:call-template name="displayHeading">
						<xsl:with-param name="id">spc_5</xsl:with-param>
						<xsl:with-param name="secnr">5</xsl:with-param>
					</xsl:call-template>
				</xsl:if>
			
				<xsl:if test="$section = '' or $section = 'spc_5' or $section = 'spc_51'">	
																																																		<!-- SECTION 5.1 -->
					<xsl:call-template name="displaySubHeading">
						<xsl:with-param name="id">spc_51</xsl:with-param>
						<xsl:with-param name="secnr">5.1</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="atcGroupCode"/>
					<xsl:call-template name="displaySeparator"/>
					<xsl:call-template name="displayElement">
						<xsl:with-param name="level">1</xsl:with-param>
						<xsl:with-param name="element">pharmacodynamic_s</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="approvalMode"/>
				</xsl:if>
					
				<xsl:call-template name="displaySeparator"/>
				
				<xsl:if test="$section = '' or $section = 'spc_5' or $section = 'spc_52'">	
																																																		<!-- SECTION 5.2 -->
					<xsl:call-template name="displaySubHeading">
						<xsl:with-param name="id">spc_52</xsl:with-param>
						<xsl:with-param name="secnr">5.2</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="displayElement">
						<xsl:with-param name="level">1</xsl:with-param>
						<xsl:with-param name="element">pharmacokinetic_s</xsl:with-param>
					</xsl:call-template>
				</xsl:if>
					
				<xsl:call-template name="displaySeparator"/>
					
				<xsl:if test="$section = '' or $section = 'spc_5' or $section = 'spc_53'">
																																																		<!-- SECTION 5.3 -->
					<xsl:call-template name="displaySubHeading">
						<xsl:with-param name="id">spc_53</xsl:with-param>
						<xsl:with-param name="secnr">5.3</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="displayElement">
						<xsl:with-param name="level">0</xsl:with-param>
						<xsl:with-param name="element">preclinical_safety_s</xsl:with-param>
					</xsl:call-template>
				</xsl:if>
			</xsl:if>

			<xsl:call-template name="displaySeparator"/>
			<xsl:call-template name="displaySeparator"/>
	
			<xsl:if test="$section = '' or substring($section, 1, 5) = 'spc_6'">
																																																		<!-- SECTION 6 -->
				<xsl:if test="$section = '' or $section = 'spc_6'">
					<xsl:call-template name="displayHeading">
						<xsl:with-param name="id">spc_6</xsl:with-param>
						<xsl:with-param name="secnr">6</xsl:with-param>
					</xsl:call-template>
				</xsl:if>
					
				<xsl:if test="$section = '' or $section = 'spc_6' or $section = 'spc_61'">
																																																		<!-- SECTION 6.1 -->
					<xsl:call-template name="displaySubHeading">
						<xsl:with-param name="id">spc_61</xsl:with-param>
						<xsl:with-param name="secnr">6.1</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="displayElement">
						<xsl:with-param name="level">2</xsl:with-param>
						<xsl:with-param name="element">excipient_all_s</xsl:with-param>
					</xsl:call-template>
				</xsl:if>
					
				<xsl:call-template name="displaySeparator"/>
				
				<xsl:if test="$section = '' or $section = 'spc_6' or $section = 'spc_62'">
																																																		<!-- SECTION 6.2 -->
					<xsl:call-template name="displaySubHeading">
						<xsl:with-param name="id">spc_62</xsl:with-param>
						<xsl:with-param name="secnr">6.2</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="displayElement">
						<xsl:with-param name="level">3</xsl:with-param>
						<xsl:with-param name="element">incompatibility_s</xsl:with-param>
					</xsl:call-template>
				</xsl:if>
					
				<xsl:call-template name="displaySeparator"/>
				
				<xsl:if test="$section = '' or $section = 'spc_6' or $section = 'spc_63'">
																																																		<!-- SECTION 6.3 -->
					<xsl:call-template name="displaySubHeading">
						<xsl:with-param name="id">spc_63</xsl:with-param>
						<xsl:with-param name="secnr">6.3</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="displayElement">
						<xsl:with-param name="level">3</xsl:with-param>
						<xsl:with-param name="element">life_shelf_s</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="displayElement">
						<xsl:with-param name="level">3</xsl:with-param>
						<xsl:with-param name="element">life_open_s</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="displayElement">
						<xsl:with-param name="level">3</xsl:with-param>
						<xsl:with-param name="element">life_reconstituted_s</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="displayElement">
						<xsl:with-param name="level">3</xsl:with-param>
						<xsl:with-param name="element">storage_reconstituted_s</xsl:with-param>
					</xsl:call-template>
				</xsl:if>
					
				<xsl:call-template name="displaySeparator"/>
					
				<xsl:if test="$section = '' or $section = 'spc_6' or $section = 'spc_64'">
																																																		<!-- SECTION 6.4 -->
					<xsl:call-template name="displaySubHeading">
						<xsl:with-param name="id">spc_64</xsl:with-param>
						<xsl:with-param name="secnr">6.4</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="displayElement">
						<xsl:with-param name="level">3</xsl:with-param>
						<xsl:with-param name="element">storage_shelf_s</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="displayElement">
						<xsl:with-param name="level">3</xsl:with-param>
						<xsl:with-param name="element">storage_open_s</xsl:with-param>
					</xsl:call-template>
					<xsl:variable name="spc_sts_64" select="/pim/documents/document[position() = $docpos]/@spc_sts_64"/>
					<xsl:if test="$spc_sts_64 != 'none'">
						<xsl:call-template name="displayText">
							<xsl:with-param name="id">spc_64a_<xsl:value-of select="$spc_sts_64"/></xsl:with-param>
						</xsl:call-template>
					</xsl:if>
				</xsl:if>
					
				<xsl:call-template name="displaySeparator"/>
					
				<xsl:if test="$section = '' or $section = 'spc_6' or $section = 'spc_65'">
																																																		<!-- SECTION 6.5 -->
					<xsl:call-template name="displaySubHeading">
						<xsl:with-param name="id">spc_65</xsl:with-param>
						<xsl:with-param name="secnr">6.5</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="displayElement">
						<xsl:with-param name="level">3</xsl:with-param>
						<xsl:with-param name="element">container_s</xsl:with-param>
					</xsl:call-template>
				</xsl:if>
					
				<xsl:call-template name="displaySeparator"/>
					
				<xsl:if test="$section = '' or $section = 'spc_6' or $section = 'spc_66'">
																																																		<!-- SECTION 6.6 -->
					<xsl:call-template name="displaySubHeading">
						<xsl:with-param name="id">spc_66</xsl:with-param>
						<xsl:with-param name="secnr">6.6</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="displayElement">
						<xsl:with-param name="level">3</xsl:with-param>
						<xsl:with-param name="element">use_s</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="displayElement">
						<xsl:with-param name="level">3</xsl:with-param>
						<xsl:with-param name="element">disposal_s</xsl:with-param>
					</xsl:call-template>
				</xsl:if>
			</xsl:if>

			<xsl:call-template name="displaySeparator"/>
			<xsl:call-template name="displaySeparator"/>
	
			<xsl:if test="$section = '' or $section = 'spc_7'">
																																																		<!-- SECTION 7 -->
				<xsl:call-template name="displayHeading">
					<xsl:with-param name="id">spc_7</xsl:with-param>
					<xsl:with-param name="secnr">7</xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="displayElement">
						<xsl:with-param name="level">0</xsl:with-param>
					<xsl:with-param name="element">holder_s</xsl:with-param>
				</xsl:call-template>
			</xsl:if>
			
			<xsl:call-template name="displaySeparator"/>
			
			<xsl:if test="$section = '' or $section = 'spc_8'">
																																																		<!-- SECTION 8 -->
				<xsl:variable name="nRegistration">
					<xsl:call-template name="countElement">
						<xsl:with-param name="level">3</xsl:with-param>
						<xsl:with-param name="element">registration</xsl:with-param>
					</xsl:call-template>
				</xsl:variable>
				<xsl:choose>
					<xsl:when test="$nRegistration > 1">
						<xsl:call-template name="displayHeading">
							<xsl:with-param name="id">spc_8_plural</xsl:with-param>
							<xsl:with-param name="secnr">8</xsl:with-param>
						</xsl:call-template>
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="displayHeading">
							<xsl:with-param name="id">spc_8_singular</xsl:with-param>
							<xsl:with-param name="secnr">8</xsl:with-param>
						</xsl:call-template>
					</xsl:otherwise>
				</xsl:choose>
				<xsl:call-template name="displayElement">
					<xsl:with-param name="level">3</xsl:with-param>
					<xsl:with-param name="element">registration</xsl:with-param>
				</xsl:call-template>
			</xsl:if>
			
			<xsl:call-template name="displaySeparator"/>
			
			<xsl:if test="$section = '' or $section = 'spc_9'">
																																																		<!-- SECTION 9 -->
				<xsl:call-template name="displayHeading">
					<xsl:with-param name="id">spc_9</xsl:with-param>
					<xsl:with-param name="secnr">9</xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="displayElement">
						<xsl:with-param name="level">3</xsl:with-param>
					<xsl:with-param name="element">authorisation</xsl:with-param>
				</xsl:call-template>
			</xsl:if>
			
			<xsl:call-template name="displaySeparator"/>
			
			<xsl:if test="$section = '' or $section = 'spc_10'">
																																																		<!-- SECTION 10 -->
				<xsl:call-template name="displayHeading">
					<xsl:with-param name="id">spc_10</xsl:with-param>
					<xsl:with-param name="secnr">10</xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="displayElement">
						<xsl:with-param name="level">2</xsl:with-param>
					<xsl:with-param name="element">revision_s</xsl:with-param>
				</xsl:call-template>
			</xsl:if>
			
			<xsl:if test="$section = '' or $section = 'spc_11'">
																																																		<!-- SECTION 11 -->
				<xsl:variable name="nDosimetry">
					<xsl:call-template name="countElement">
						<xsl:with-param name="level">2</xsl:with-param>
						<xsl:with-param name="element">dosimetry_s</xsl:with-param>
					</xsl:call-template>
				</xsl:variable>
				<xsl:if test="$nDosimetry > 0">
					
					<xsl:call-template name="displaySeparator"/>
					
					<xsl:call-template name="displayHeading">
						<xsl:with-param name="id">spc_11</xsl:with-param>
						<xsl:with-param name="secnr">11</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="displayElement">
						<xsl:with-param name="level">2</xsl:with-param>
						<xsl:with-param name="element">dosimetry_s</xsl:with-param>
					</xsl:call-template>
				</xsl:if>
			</xsl:if>
			
			<xsl:if test="$section = '' or $section = 'spc_12'">
																																																		<!-- SECTION 12 -->
				<xsl:variable name="nInstructionsRadiopharm">
					<xsl:call-template name="countElement">
						<xsl:with-param name="level">3</xsl:with-param>
						<xsl:with-param name="element">instructions_radiopharm_s</xsl:with-param>
					</xsl:call-template>
				</xsl:variable>
				<xsl:if test="$nInstructionsRadiopharm > 0">			
					
					<xsl:call-template name="displaySeparator"/>
					
					<xsl:call-template name="displayHeading">
						<xsl:with-param name="id">spc_12</xsl:with-param>
						<xsl:with-param name="secnr">12</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="displayElement">
						<xsl:with-param name="level">3</xsl:with-param>
						<xsl:with-param name="element">instructions_radiopharm_s</xsl:with-param>
					</xsl:call-template>
				</xsl:if>
			</xsl:if>
	
			<xsl:call-template name="displaySeparator"/>
			<xsl:call-template name="displaySeparator"/>
	
																																																		<!-- END -->
			<xsl:variable name="spc_sts_end" select="/pim/documents/document[position() = $docpos]/@spc_sts_end"/>
			<xsl:if test="$spc_sts_end = 'yes'">
				<xsl:call-template name="displayNode">
					<xsl:with-param name="id">spc_end</xsl:with-param>
				</xsl:call-template>
			</xsl:if>

		</table>
		<br/><br/>
		<xsl:if test="$section ='' and $caller = ''">
																																																	<!-- FOOTNOTE -->
			<font size="-5">SPC style sheet version <xsl:value-of select="$xsl-ver"/></font>
		</xsl:if>
		<br/>
	</body>
</html>
</xsl:template>

<!-- Special case of Section 1: name of the medicinal product -->
<xsl:template name="nameMedicinalProduct">
	<xsl:variable name="nQualBeforeInv">
		<xsl:call-template name="countDifferentElement">
			<xsl:with-param name="level">3</xsl:with-param>
			<xsl:with-param name="element">qual_before_inv</xsl:with-param>
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="nQualAfterInv">
		<xsl:call-template name="countDifferentElement">
			<xsl:with-param name="level">3</xsl:with-param>
			<xsl:with-param name="element">qual_after_inv</xsl:with-param>
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="nStrength">
		<xsl:call-template name="countElement">
			<xsl:with-param name="level">2</xsl:with-param>
			<xsl:with-param name="element">strength</xsl:with-param>
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="nQualStrength">
		<xsl:call-template name="countDifferentElement">
			<xsl:with-param name="level">3</xsl:with-param>
			<xsl:with-param name="element">qual_strength</xsl:with-param>
		</xsl:call-template>
	</xsl:variable>
	<xsl:variable name="nQualForm">
		<xsl:call-template name="countDifferentElement">
			<xsl:with-param name="level">3</xsl:with-param>
			<xsl:with-param name="element">qual_form_s</xsl:with-param>
		</xsl:call-template>
	</xsl:variable>
	
	<xsl:choose>
		<xsl:when test="contains($nQualBeforeInv, 'N') or contains($nQualAfterInv, 'N') or contains($nQualStrength, 'N') or contains($nQualForm, 'N')">
			<xsl:choose>
				<xsl:when test="$nStrength > 1">
					<xsl:for-each select="/pim/documents/document[position() = $docpos]/pi-level">
						<xsl:variable name="level_id" select="@ref-id"/>
						<xsl:for-each select="key('level_id', $level_id)//strength">
							<xsl:variable name="str-pos" select="position()"/>
							<xsl:for-each select="../level_presentation">
								<tr>
									<xsl:if test="$caller = 'pimrs'">
										<td><xsl:text> </xsl:text></td>
									</xsl:if>
									<td width="100%">
										<xsl:for-each select="qual_before_inv/pi-group/pi-leaf">
											<xsl:call-template name="displayTemplateText">
												<xsl:with-param name="id" select="@ref-id"/>
											</xsl:call-template>
										</xsl:for-each>
										<xsl:for-each select="../../../invented_name/pi-group/pi-leaf">
											<xsl:call-template name="displayTemplateText">
												<xsl:with-param name="id" select="@ref-id"/>
											</xsl:call-template>
										</xsl:for-each>
										<xsl:for-each select="qual_after_inv/pi-group/pi-leaf">
											<xsl:call-template name="displayTemplateText">
												<xsl:with-param name="id" select="@ref-id"/>
											</xsl:call-template>
										</xsl:for-each>
										<xsl:for-each select="../strength[$str-pos]/pi-group/pi-leaf">
											<xsl:call-template name="displayTemplateText">
												<xsl:with-param name="id" select="@ref-id"/>
											</xsl:call-template>
										</xsl:for-each>
										<xsl:for-each select="qual_strength/pi-group/pi-leaf">
											<xsl:call-template name="displayTemplateText">
												<xsl:with-param name="id" select="@ref-id"/>
											</xsl:call-template>
										</xsl:for-each>
										<xsl:for-each select="../../form_inline_s/pi-group/pi-leaf">
											<xsl:call-template name="displayTemplateText">
												<xsl:with-param name="id" select="@ref-id"/>
											</xsl:call-template>
										</xsl:for-each>
										<xsl:for-each select="qual_form_s/pi-group/pi-leaf">
											<xsl:call-template name="displayTemplateText">
												<xsl:with-param name="id" select="@ref-id"/>
											</xsl:call-template>
										</xsl:for-each>
									</td>
								</tr>
							</xsl:for-each>
						</xsl:for-each>
					</xsl:for-each>
				</xsl:when>
				<xsl:otherwise>
					<xsl:for-each select="/pim/documents/document[position() = $docpos]/pi-level">
						<xsl:variable name="level_id" select="@ref-id"/>
						<xsl:for-each select="key('level_id', $level_id)//level_presentation">
							<tr>
								<xsl:if test="$caller = 'pimrs'">
									<td><xsl:text> </xsl:text></td>
								</xsl:if>
								<td width="100%">
									<xsl:for-each select="qual_before_inv/pi-group/pi-leaf">
										<xsl:call-template name="displayTemplateText">
											<xsl:with-param name="id" select="@ref-id"/>
										</xsl:call-template>
									</xsl:for-each>
									<xsl:call-template name="displayElement">
										<xsl:with-param name="level">0</xsl:with-param>
										<xsl:with-param name="element">invented_name</xsl:with-param>
										<xsl:with-param name="mode">text</xsl:with-param>
									</xsl:call-template>
									<xsl:for-each select="qual_after_inv/pi-group/pi-leaf">
										<xsl:call-template name="displayTemplateText">
											<xsl:with-param name="id" select="@ref-id"/>
										</xsl:call-template>
									</xsl:for-each>
									<xsl:call-template name="displayElement">
										<xsl:with-param name="level">2</xsl:with-param>
										<xsl:with-param name="element">strength</xsl:with-param>
										<xsl:with-param name="mode">text</xsl:with-param>
									</xsl:call-template>
									<xsl:for-each select="qual_strength/pi-group/pi-leaf">
										<xsl:call-template name="displayTemplateText">
											<xsl:with-param name="id" select="@ref-id"/>
										</xsl:call-template>
									</xsl:for-each>
									<xsl:call-template name="displayElement">
										<xsl:with-param name="level">1</xsl:with-param>
										<xsl:with-param name="element">form_inline_s</xsl:with-param>
										<xsl:with-param name="mode">text</xsl:with-param>
									</xsl:call-template>
									<xsl:for-each select="qual_form_s/pi-group/pi-leaf">
										<xsl:call-template name="displayTemplateText">
											<xsl:with-param name="id" select="@ref-id"/>
										</xsl:call-template>
									</xsl:for-each>
								</td>
							</tr>
						</xsl:for-each>
					</xsl:for-each>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:when>
		<xsl:otherwise>
			<xsl:choose>
				<xsl:when test="$nStrength > 1">
					<xsl:for-each select="/pim/documents/document[position() = $docpos]/pi-level">
						<xsl:variable name="level_id" select="@ref-id"/>
						<xsl:for-each select="key('level_id', $level_id)//strength">
							<tr>
								<xsl:if test="$caller = 'pimrs'">
									<td><xsl:text> </xsl:text></td>
								</xsl:if>
								<td width="100%">
									<xsl:call-template name="displayElement">
										<xsl:with-param name="level">3</xsl:with-param>
										<xsl:with-param name="element">qual_before_inv</xsl:with-param>
										<xsl:with-param name="mode">text</xsl:with-param>
									</xsl:call-template>
									<xsl:call-template name="displayElement">
										<xsl:with-param name="level">0</xsl:with-param>
										<xsl:with-param name="element">invented_name</xsl:with-param>
										<xsl:with-param name="mode">text</xsl:with-param>
									</xsl:call-template>
									<xsl:call-template name="displayElement">
										<xsl:with-param name="level">3</xsl:with-param>
										<xsl:with-param name="element">qual_after_inv</xsl:with-param>
										<xsl:with-param name="mode">text</xsl:with-param>
									</xsl:call-template>
									<xsl:for-each select="pi-group/pi-leaf">
										<xsl:call-template name="displayTemplateText">
											<xsl:with-param name="id" select="@ref-id"/>
										</xsl:call-template>
									</xsl:for-each>
									<xsl:call-template name="displayElement">
										<xsl:with-param name="level">3</xsl:with-param>
										<xsl:with-param name="element">qual_strength</xsl:with-param>
										<xsl:with-param name="mode">text</xsl:with-param>
									</xsl:call-template>
									<xsl:call-template name="displayElement">
										<xsl:with-param name="level">1</xsl:with-param>
										<xsl:with-param name="element">form_inline_s</xsl:with-param>
										<xsl:with-param name="mode">text</xsl:with-param>
									</xsl:call-template>
									<xsl:call-template name="displayElement">
										<xsl:with-param name="level">3</xsl:with-param>
										<xsl:with-param name="element">qual_form_s</xsl:with-param>
										<xsl:with-param name="mode">text</xsl:with-param>
									</xsl:call-template>
								</td>
							</tr>
						</xsl:for-each>
					</xsl:for-each>
				</xsl:when>
				<xsl:otherwise>
					<tr>
						<xsl:if test="$caller = 'pimrs'">
							<td><xsl:text> </xsl:text></td>
						</xsl:if>
						<td width="100%">
							<xsl:call-template name="displayElement">
								<xsl:with-param name="level">3</xsl:with-param>
								<xsl:with-param name="element">qual_before_inv</xsl:with-param>
								<xsl:with-param name="mode">text</xsl:with-param>
							</xsl:call-template>
							<xsl:call-template name="displayElement">
								<xsl:with-param name="level">0</xsl:with-param>
								<xsl:with-param name="element">invented_name</xsl:with-param>
								<xsl:with-param name="mode">text</xsl:with-param>
							</xsl:call-template>
							<xsl:call-template name="displayElement">
								<xsl:with-param name="level">3</xsl:with-param>
								<xsl:with-param name="element">qual_after_inv</xsl:with-param>
								<xsl:with-param name="mode">text</xsl:with-param>
							</xsl:call-template>
							<xsl:call-template name="displayElement">
								<xsl:with-param name="level">2</xsl:with-param>
								<xsl:with-param name="element">strength</xsl:with-param>
								<xsl:with-param name="mode">text</xsl:with-param>
							</xsl:call-template>
							<xsl:call-template name="displayElement">
								<xsl:with-param name="level">3</xsl:with-param>
								<xsl:with-param name="element">qual_strength</xsl:with-param>
								<xsl:with-param name="mode">text</xsl:with-param>
							</xsl:call-template>
							<xsl:call-template name="displayElement">
								<xsl:with-param name="level">1</xsl:with-param>
								<xsl:with-param name="element">form_inline_s</xsl:with-param>
								<xsl:with-param name="mode">text</xsl:with-param>
							</xsl:call-template>
							<xsl:call-template name="displayElement">
								<xsl:with-param name="level">3</xsl:with-param>
								<xsl:with-param name="element">qual_form_s</xsl:with-param>
								<xsl:with-param name="mode">text</xsl:with-param>
							</xsl:call-template>
						</td>
					</tr>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- Special case of Section 3: pharmaceutical form -->
<xsl:template name="pharmaceuticalForm">
	<xsl:variable name="nQualFormSection">
		<xsl:call-template name="countDifferentElement">
			<xsl:with-param name="level">3</xsl:with-param>
			<xsl:with-param name="element">qual_form_section_s</xsl:with-param>
		</xsl:call-template>
	</xsl:variable>
		
	<xsl:choose>
		<xsl:when test="contains($nQualFormSection, 'N')">
			<xsl:for-each select="/pim/documents/document[position() = $docpos]/pi-level">
				<xsl:variable name="level_id" select="@ref-id"/>
				<xsl:for-each select="key('level_id', $level_id)//level_presentation">
					<tr>
						<xsl:if test="$caller = 'pimrs'">
							<td><xsl:text> </xsl:text></td>
						</xsl:if>
						<td width="100%">
							<xsl:for-each select="../../form_section_s/pi-group/pi-leaf">
								<xsl:call-template name="displayTemplateText">
									<xsl:with-param name="id" select="@ref-id"/>
								</xsl:call-template>
							</xsl:for-each>
							<xsl:for-each select="qual_form_section_s/pi-group/pi-leaf">
								<xsl:call-template name="displayTemplateText">
									<xsl:with-param name="id" select="@ref-id"/>
								</xsl:call-template>
							</xsl:for-each>
						</td>
					</tr>
				</xsl:for-each>
			</xsl:for-each>
		</xsl:when>
		<xsl:otherwise>
			<tr>
				<xsl:if test="$caller = 'pimrs'">
					<td><xsl:text> </xsl:text></td>
				</xsl:if>
				<td width="100%">
					<xsl:call-template name="displayElement">
						<xsl:with-param name="level">1</xsl:with-param>
						<xsl:with-param name="element">form_section_s</xsl:with-param>
						<xsl:with-param name="mode">text</xsl:with-param>
					</xsl:call-template>
					<xsl:call-template name="displayElement">
						<xsl:with-param name="level">3</xsl:with-param>
						<xsl:with-param name="element">qual_form_section_s</xsl:with-param>
						<xsl:with-param name="mode">text</xsl:with-param>
					</xsl:call-template>
				</td>
			</tr>
		</xsl:otherwise>
	</xsl:choose>
</xsl:template>

<!-- Special case of Section 5.1: ATC group and code -->
<xsl:template name="atcGroupCode">
	<tr>
		<xsl:if test="$caller = 'pimrs'">
			<td><xsl:text> </xsl:text></td>
		</xsl:if>
		<td width="100%">
			<xsl:call-template name="getHeadingText">
				<xsl:with-param name="id">spc_51a</xsl:with-param>
			</xsl:call-template>
			<xsl:text> </xsl:text>
			<xsl:call-template name="displayElement">
				<xsl:with-param name="level">0</xsl:with-param>
				<xsl:with-param name="element">atc_group_s</xsl:with-param>
				<xsl:with-param name="mode">text</xsl:with-param>
			</xsl:call-template>
			<xsl:call-template name="getHeadingText">
				<xsl:with-param name="id">spc_51b</xsl:with-param>
			</xsl:call-template>
			<xsl:text> </xsl:text>
			<xsl:call-template name="displayElement">
				<xsl:with-param name="level">0</xsl:with-param>
				<xsl:with-param name="element">atc_code</xsl:with-param>
				<xsl:with-param name="mode">text</xsl:with-param>
			</xsl:call-template>
		</td>
	</tr>
</xsl:template>

<!-- Special case of Section 5.1: approval mode -->
<xsl:template name="approvalMode">
	<tr>
		<xsl:if test="$caller = 'pimrs'">
			<td><xsl:text> </xsl:text></td>
		</xsl:if>
		<td width="100%">
			<xsl:variable name="mode"><xsl:value-of select="/pim/level_product/approval/@mode"/></xsl:variable>
			<xsl:if test="$mode != 'complete'">
				<xsl:call-template name="displayText">
					<xsl:with-param name="id">spc_51_<xsl:value-of select="$mode"/>_a</xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="displayText">
					<xsl:with-param name="id">spc_51_<xsl:value-of select="$mode"/>_b</xsl:with-param>
				</xsl:call-template>
				<xsl:call-template name="displayText">
					<xsl:with-param name="id">spc_51_<xsl:value-of select="$mode"/>_c</xsl:with-param>
				</xsl:call-template>
			</xsl:if>
		</td>
	</tr>
</xsl:template>

</xsl:stylesheet>